[][src]Struct opcua_server::address_space::method::MethodBuilder

pub struct MethodBuilder { /* fields omitted */ }

A builder for constructing a node of same name. This can be used as an easy way to create a node and the references it has to another node in a simple fashion.

Implementations

impl MethodBuilder[src]

pub fn new<T, S>(node_id: &NodeId, browse_name: T, display_name: S) -> Self where
    T: Into<QualifiedName>,
    S: Into<LocalizedText>, 
[src]

Creates a builder for a node. All nodes are required to su

pub fn get_node_id(&self) -> NodeId[src]

pub fn is_valid(&self) -> bool[src]

Tests that the builder is in a valid state to build or insert the node.

pub fn description<V>(self, description: V) -> Self where
    V: Into<LocalizedText>, 
[src]

Sets the description of the node

pub fn reference<T>(
    self,
    node_id: T,
    reference_type_id: ReferenceTypeId,
    reference_direction: ReferenceDirection
) -> Self where
    T: Into<NodeId>, 
[src]

Adds a reference to the node

pub fn organizes<T>(self, organizes_id: T) -> Self where
    T: Into<NodeId>, 
[src]

Indicates this node organizes another node by its id.

pub fn organized_by<T>(self, organized_by_id: T) -> Self where
    T: Into<NodeId>, 
[src]

Indicates this node is organised by another node by its id

pub fn build(self) -> Method[src]

Yields a built node. This function will panic if the node is invalid. Note that calling this function discards any references for the node, so there is no purpose in adding references if you intend to call this method.

pub fn insert(self, address_space: &mut AddressSpace) -> bool[src]

Inserts the node into the address space, including references. This function will panic if the node is in an invalid state.

impl MethodBuilder[src]

pub fn component_of<T>(self, component_of_id: T) -> Self where
    T: Into<NodeId>, 
[src]

pub fn has_component<T>(self, has_component_id: T) -> Self where
    T: Into<NodeId>, 
[src]

impl MethodBuilder[src]

pub fn generates_event<T>(self, event_type: T) -> Self where
    T: Into<NodeId>, 
[src]

impl MethodBuilder[src]

pub fn output_args(
    self,
    address_space: &mut AddressSpace,
    arguments: &[Argument]
) -> Self
[src]

Specify output arguments from the method. This will create an OutputArguments variable child of the method which describes the out parameters.

pub fn input_args(
    self,
    address_space: &mut AddressSpace,
    arguments: &[Argument]
) -> Self
[src]

Specify input arguments to the method. This will create an InputArguments variable child of the method which describes the in parameters.

pub fn callback(self, callback: Box<dyn Method + Send + Sync>) -> Self[src]