[−][src]Trait opcua_server::callbacks::Method
Called by the Method service when it invokes a method
Required methods
fn call(
&mut self,
session: &mut Session,
request: &CallMethodRequest
) -> Result<CallMethodResult, StatusCode>
&mut self,
session: &mut Session,
request: &CallMethodRequest
) -> Result<CallMethodResult, StatusCode>
A method is registered via the address space to a method id and optionally an object id. When a client sends a CallRequest / CallMethod request, the registered object will be invoked to handle the call.