Struct opcua_server::config::ServerConfig[][src]

pub struct ServerConfig {
Show 14 fields pub application_name: String, pub application_uri: String, pub product_uri: String, pub pki_dir: PathBuf, pub create_sample_keypair: bool, pub trust_client_certs: bool, pub discovery_server_url: Option<String>, pub tcp_config: TcpConfig, pub limits: ServerLimits, pub locale_ids: Vec<String>, pub user_tokens: BTreeMap<String, ServerUserToken>, pub discovery_urls: Vec<String>, pub default_endpoint: Option<String>, pub endpoints: BTreeMap<String, ServerEndpoint>,
}

Fields

application_name: String

An id for this server

application_uri: String

A description for this server

product_uri: String

Product url

pki_dir: PathBuf

pki folder, either absolute or relative to executable

create_sample_keypair: bool

Autocreates public / private keypair if they don’t exist. For testing/samples only since you do not have control of the values

trust_client_certs: bool

Auto trusts client certificates. For testing/samples only unless you’re sure what you’re doing.

discovery_server_url: Option<String>

Url to a discovery server - adding this string causes the server to assume you wish to register the server with a discovery server.

tcp_config: TcpConfig

tcp configuration information

limits: ServerLimits

Server limits

locale_ids: Vec<String>

Supported locale ids

user_tokens: BTreeMap<String, ServerUserToken>

User tokens

discovery_urls: Vec<String>

discovery endpoint url which may or may not be the same as the service endpoints below.

default_endpoint: Option<String>

Default endpoint id

endpoints: BTreeMap<String, ServerEndpoint>

Endpoints supported by the server

Implementations

Returns a opc.tcp://server:port url that paths can be appended onto

Find the default endpoint

Find the first endpoint that matches the specified url, security policy and message security mode.