Struct opcua_server::config::ServerUserToken[][src]

pub struct ServerUserToken {
    pub user: String,
    pub pass: Option<String>,
    pub x509: Option<String>,
    pub thumbprint: Option<Thumbprint>,
}

Fields

user: String

User name

pass: Option<String>

Password

x509: Option<String>thumbprint: Option<Thumbprint>

Implementations

Create a user pass token

Create an X509 token.

Read an X509 user token’s certificate from disk and then hold onto the thumbprint for it.

Test if the token is valid. This does not care for x509 tokens if the cert is present on the disk or not.