[][src]Struct opcua_server::diagnostics::ServerDiagnostics

pub struct ServerDiagnostics { /* fields omitted */ }

Structure that captures diagnostics information for the server

Methods

impl ServerDiagnostics[src]

pub fn server_diagnostics_summary(&self) -> &ServerDiagnosticsSummaryDataType[src]

Return a completed summary of the server diagnostics as they stand. This structure is used to fill the address space stats about the server.