[][src]Struct opcua_server::historical::HistoryServerCapabilities

pub struct HistoryServerCapabilities {
    pub access_history_data: bool,
    pub access_history_events: bool,
    pub max_return_data: u32,
    pub max_return_events: u32,
    pub insert_data: bool,
    pub replace_data: bool,
    pub update_data: bool,
    pub delete_raw: bool,
    pub delete_at_time: bool,
    pub insert_event: bool,
    pub replace_event: bool,
    pub update_event: bool,
    pub delete_event: bool,
    pub insert_annotation: bool,
}

Values that should be set in the address space via AddressSpace::set_history_server_capabilities() to denote to clients what history capabilities the server has.

Fields

access_history_data: boolaccess_history_events: boolmax_return_data: u32max_return_events: u32insert_data: boolreplace_data: boolupdate_data: booldelete_raw: booldelete_at_time: boolinsert_event: boolreplace_event: boolupdate_event: booldelete_event: boolinsert_annotation: bool