InMemoryNodeManager

Struct InMemoryNodeManager 

pub struct InMemoryNodeManager<TImpl> { /* private fields */ }
A node manager that stores its nodes in an in-memory AddressSpace. This only supports a static list of namespaces, and a attributes stored in memory.

Implementations of custom behavior are provided with a type implementing InMemoryNodeManagerImpl.

Implementations

Source

impl<TImpl: InMemoryNodeManagerImpl> InMemoryNodeManager<TImpl>

pub fn inner(&self) -> &TImpl

Return the inner InMemoryNodeManagerImpl.

pub fn address_space(&self) -> &Arc<RwLock<AddressSpace>>

Get the address space.

pub fn namespaces(&self) -> &HashMap<u16, String>

Get a reference to the namespaces managed by this node manager, by namespace index.

pub fn set_attributes<'a>( &self, subscriptions: &SubscriptionCache, values: impl Iterator<Item = (&'a NodeId, AttributeId, Variant)>, ) -> Result<(), StatusCode>

Set the attributes given in values and notify any subscriptions about the changes.

To set values, use InMemoryNodeManager::set_values.

pub fn set_attribute( &self, subscriptions: &SubscriptionCache, id: &NodeId, attribute_id: AttributeId, value: Variant, ) -> Result<(), StatusCode>

Set the attribute given by attribute_id on the node with ID id to value.

pub fn set_values<'a>( &self, subscriptions: &SubscriptionCache, values: impl Iterator<Item = (&'a NodeId, Option<&'a NumericRange>, DataValue)>, ) -> Result<(), StatusCode>

Set variable values with updates given by values, notifying any subscriptions of the changes.

pub fn set_value( &self, subscriptions: &SubscriptionCache, id: &NodeId, index_range: Option<&NumericRange>, value: DataValue, ) -> Result<(), StatusCode>

Set the variable value to value, using index_range, on the node with ID id.