BrowseNode

Struct BrowseNode 

pub struct BrowseNode { /* private fields */ }
Container for a node being browsed and the result of the browse operation.

Implementations

Source

impl BrowseNode

pub fn set_status(&mut self, status: StatusCode)

Set the response status, you should make sure to set this if you own the node being browsed. It defaults to BadNodeIdUnknown.

pub fn continuation_point<T: Send + Sync + 'static>(&self) -> Option<&T>

Get the continuation point created during the last request.

pub fn continuation_point_mut<T: Send + Sync + 'static>( &mut self, ) -> Option<&mut T>

Get the continuation point created during the last request.

pub fn take_continuation_point<T: Send + Sync + 'static>( &mut self, ) -> Option<Box<T>>

Consume the continuation point created during the last request.

pub fn set_next_continuation_point<T: Send + Sync + 'static>( &mut self, continuation_point: Box<T>, )

Set the continuation point that will be returned to the client.

pub fn result_len(&self) -> usize

Get the current number of added references.

pub fn remaining(&self) -> usize

Get the number of references that can be added to this result before stopping and returning a continuation point.

pub fn add_unchecked(&mut self, reference: ReferenceDescription)

Add a reference to the results list, without verifying that it is valid. If you do this, you are responsible for validating filters, and requested fields on each reference.

pub fn allows_reference_type( &self, ty: &NodeId, type_tree: &dyn TypeTree, ) -> bool

Return true if nodes with the given reference type ID should be returned.

pub fn allows_node_class(&self, node_class: NodeClass) -> bool

Return true if nodes with the given node class should be returned.

pub fn allows_forward(&self) -> bool

Return true if references with forward direction should be returned.

pub fn allows_inverse(&self) -> bool

Return true if references with inverse direction should be returned.

pub fn matches_filter( &self, type_tree: &dyn TypeTree, reference: &ReferenceDescription, ) -> bool

Return true if the given reference should be returned.

pub fn add( &mut self, type_tree: &dyn TypeTree, reference: ReferenceDescription, ) -> AddReferenceResult

Add a reference, validating that it matches the filters, and returning Added if it was added. If the browse node is full, this will return Full containing the given reference if max_references_per_node would be exceeded. In this case you are responsible for setting a ContinuationPoint to ensure all references are included. This will clear any fields not required by ResultMask.

pub fn include_subtypes(&self) -> bool

Whether to include subtypes of the reference_type_id.

pub fn node_id(&self) -> &NodeId

Node ID to browse.

pub fn browse_direction(&self) -> BrowseDirection

Direction to browse.

pub fn node_class_mask(&self) -> &NodeClassMask

Mask for node classes to return. If this is empty, all node classes should be returned.

pub fn result_mask(&self) -> BrowseDescriptionResultMask

Mask for attributes to return.

pub fn reference_type_id(&self) -> &NodeId

Reference type ID of references to return. Subject to include_subtypes.

pub fn is_completed(&self) -> bool

Returns whether this node is completed in this invocation of the Browse or BrowseNext service. If this returns true, no new nodes should be added.

pub fn push_external_reference(&mut self, reference: ExternalReference)

Add an external reference to the result. This will be resolved by calling into a different node manager.

pub fn get_external_refs(&self) -> impl Iterator<Item = &NodeId>

Get an iterator over the external references.

pub fn any_external_refs(&self) -> bool

Return true if there are any external references to evaluate.