[][src]Struct opcua_server::prelude::byte_string::ByteString

pub struct ByteString {
    pub value: Option<Vec<u8>>,
}

A sequence of octets.

Fields

value: Option<Vec<u8>>

Methods

impl ByteString[src]

pub fn null() -> ByteString[src]

Create a null string (not the same as an empty string)

pub fn is_null(&self) -> bool[src]

Test if the string is null

pub fn is_null_or_empty(&self) -> bool[src]

Test if the string is null or empty

pub fn from_base64(data: &str) -> Option<ByteString>[src]

Creates a byte string from a Base64 encoded string

pub fn as_base64(&self) -> String[src]

Encodes the bytestring as a Base64 encoded string

pub fn random(number_of_bytes: usize) -> ByteString[src]

Create a byte string with a number of random characters. Can be used to create a nonce or a similar reason.