[][src]Function opcua_server::prelude::encoding::read_array

pub fn read_array<S, T>(
    stream: &mut S,
    decoding_limits: &DecodingLimits
) -> Result<Option<Vec<T>>, StatusCode> where
    S: Read,
    T: BinaryEncoder<T>, 

Reads an array of the encoded type from a stream, preserving distinction between null array and empty array