[−][src]Struct opcua_server::prelude::encoding::DecodingLimits
Fields
max_string_length: usizeMaximum length in bytes (not chars!) of a string. 0 actually means 0, i.e. no string permitted
max_byte_string_length: usizeMaximum length in bytes of a byte string. 0 actually means 0, i.e. no byte string permitted
max_array_length: usizeMaximum number of array elements. 0 actually means 0, i.e. no array permitted
Methods
impl DecodingLimits[src]
pub fn minimal() -> DecodingLimits[src]
This can be useful for decoding extension objects where the payload is not expected to contain any string or array.