[][src]Enum opcua_server::prelude::ExtensionObjectEncoding

pub enum ExtensionObjectEncoding {
    None,
    ByteString(ByteString),
    XmlElement(UAString),
}

Enumeration that holds the kinds of encoding that an ExtensionObject data may be encoded with.

Variants

None

For an extension object with nothing encoded with it

ByteString(ByteString)

For an extension object with data encoded in a ByteString

XmlElement(UAString)

For an extension object with data encoded in an XML string