[][src]Enum opcua_server::prelude::MessageSecurityMode

pub enum MessageSecurityMode {
    Invalid,
    None,
    Sign,
    SignAndEncrypt,
}

The MessageSecurityMode is an enumeration that specifies what security should be applied to messages exchanges during a Session.

Variants

Invalid

The MessageSecurityMode is invalid. This value is the default value to ensure that unless explicitly set, a connection will be rejected.

None

No security is applied. This assumes a plaintext security policy.

Sign

All messages are signed but not encrypted.

SignAndEncrypt

All messages are signed and encrypted.