Enum opcua_server::prelude::VariantTypeId
source · pub enum VariantTypeId {
Show 26 variants
Empty,
Boolean,
SByte,
Byte,
Int16,
UInt16,
Int32,
UInt32,
Int64,
UInt64,
Float,
Double,
String,
DateTime,
Guid,
StatusCode,
ByteString,
XmlElement,
QualifiedName,
LocalizedText,
NodeId,
ExpandedNodeId,
ExtensionObject,
DataValue,
Array,
MultiDimensionArray,
}Expand description
The variant type id is the type of the variant but without its payload.
Variants
Empty
Boolean
SByte
Byte
Int16
UInt16
Int32
UInt32
Int64
UInt64
Float
Double
String
DateTime
Guid
StatusCode
ByteString
XmlElement
QualifiedName
LocalizedText
NodeId
ExpandedNodeId
ExtensionObject
DataValue
Array
MultiDimensionArray
Implementations
sourceimpl VariantTypeId
impl VariantTypeId
sourcepub fn is_numeric(&self) -> bool
pub fn is_numeric(&self) -> bool
Tests and returns true if the variant holds a numeric type