Struct opcua_server::prelude::service_types::CreateSessionRequest
source · [−]pub struct CreateSessionRequest {
pub request_header: RequestHeader,
pub client_description: ApplicationDescription,
pub server_uri: UAString,
pub endpoint_url: UAString,
pub session_name: UAString,
pub client_nonce: ByteString,
pub client_certificate: ByteString,
pub requested_session_timeout: f64,
pub max_response_message_size: u32,
}Fields
request_header: RequestHeaderclient_description: ApplicationDescriptionserver_uri: UAStringendpoint_url: UAStringsession_name: UAStringclient_nonce: ByteStringclient_certificate: ByteStringrequested_session_timeout: f64max_response_message_size: u32Trait Implementations
sourceimpl BinaryEncoder<CreateSessionRequest> for CreateSessionRequest
impl BinaryEncoder<CreateSessionRequest> for CreateSessionRequest
sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
sourcefn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
fn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
Encodes the instance to the write stream.
sourcefn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<CreateSessionRequest, StatusCode> where
S: Read,
fn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<CreateSessionRequest, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a BadDecodingError as soon as possible. Read more
fn encode_to_vec(&self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
sourceimpl Clone for CreateSessionRequest
impl Clone for CreateSessionRequest
sourcefn clone(&self) -> CreateSessionRequest
fn clone(&self) -> CreateSessionRequest
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for CreateSessionRequest
impl Debug for CreateSessionRequest
sourceimpl Into<SupportedMessage> for CreateSessionRequest
impl Into<SupportedMessage> for CreateSessionRequest
sourcefn into(self) -> SupportedMessage
fn into(self) -> SupportedMessage
Performs the conversion.
sourceimpl MessageInfo for CreateSessionRequest
impl MessageInfo for CreateSessionRequest
sourceimpl PartialEq<CreateSessionRequest> for CreateSessionRequest
impl PartialEq<CreateSessionRequest> for CreateSessionRequest
sourcefn eq(&self, other: &CreateSessionRequest) -> bool
fn eq(&self, other: &CreateSessionRequest) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &CreateSessionRequest) -> bool
fn ne(&self, other: &CreateSessionRequest) -> bool
This method tests for !=.
impl StructuralPartialEq for CreateSessionRequest