pub struct ModifySubscriptionRequest {
pub request_header: RequestHeader,
pub subscription_id: u32,
pub requested_publishing_interval: f64,
pub requested_lifetime_count: u32,
pub requested_max_keep_alive_count: u32,
pub max_notifications_per_publish: u32,
pub priority: u8,
}Fields
request_header: RequestHeadersubscription_id: u32requested_publishing_interval: f64requested_lifetime_count: u32requested_max_keep_alive_count: u32max_notifications_per_publish: u32priority: u8Trait Implementations
sourceimpl BinaryEncoder<ModifySubscriptionRequest> for ModifySubscriptionRequest
impl BinaryEncoder<ModifySubscriptionRequest> for ModifySubscriptionRequest
sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
sourcefn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
fn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
Encodes the instance to the write stream.
sourcefn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<ModifySubscriptionRequest, StatusCode> where
S: Read,
fn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<ModifySubscriptionRequest, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a BadDecodingError as soon as possible. Read more
fn encode_to_vec(&self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
sourceimpl Clone for ModifySubscriptionRequest
impl Clone for ModifySubscriptionRequest
sourcefn clone(&self) -> ModifySubscriptionRequest
fn clone(&self) -> ModifySubscriptionRequest
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ModifySubscriptionRequest
impl Debug for ModifySubscriptionRequest
sourceimpl Into<SupportedMessage> for ModifySubscriptionRequest
impl Into<SupportedMessage> for ModifySubscriptionRequest
sourcefn into(self) -> SupportedMessage
fn into(self) -> SupportedMessage
Performs the conversion.
sourceimpl PartialEq<ModifySubscriptionRequest> for ModifySubscriptionRequest
impl PartialEq<ModifySubscriptionRequest> for ModifySubscriptionRequest
sourcefn eq(&self, other: &ModifySubscriptionRequest) -> bool
fn eq(&self, other: &ModifySubscriptionRequest) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ModifySubscriptionRequest) -> bool
fn ne(&self, other: &ModifySubscriptionRequest) -> bool
This method tests for !=.
impl StructuralPartialEq for ModifySubscriptionRequest