Struct opcua_server::prelude::AcknowledgeMessage [−][src]
pub struct AcknowledgeMessage {
pub message_header: MessageHeader,
pub protocol_version: u32,
pub receive_buffer_size: u32,
pub send_buffer_size: u32,
pub max_message_size: u32,
pub max_chunk_count: u32,
}Expand description
Implementation of the ACK message in OPC UA
Fields
message_header: MessageHeaderprotocol_version: u32receive_buffer_size: u32send_buffer_size: u32max_message_size: u32max_chunk_count: u32Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<AcknowledgeMessage, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<AcknowledgeMessage, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.