Struct opcua_server::prelude::AddNodesRequest [−][src]
pub struct AddNodesRequest {
pub request_header: RequestHeader,
pub nodes_to_add: Option<Vec<AddNodesItem, Global>>,
}Fields
request_header: RequestHeadernodes_to_add: Option<Vec<AddNodesItem, Global>>Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<AddNodesRequest, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<AddNodesRequest, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.