Struct opcua_server::prelude::AggregateConfiguration [−][src]
pub struct AggregateConfiguration {
pub use_server_capabilities_defaults: bool,
pub treat_uncertain_as_bad: bool,
pub percent_data_bad: u8,
pub percent_data_good: u8,
pub use_sloped_extrapolation: bool,
}Fields
use_server_capabilities_defaults: booltreat_uncertain_as_bad: boolpercent_data_bad: u8percent_data_good: u8use_sloped_extrapolation: boolTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<AggregateConfiguration, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<AggregateConfiguration, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.