Struct opcua_server::prelude::ApplicationDescription [−][src]
pub struct ApplicationDescription {
pub application_uri: UAString,
pub product_uri: UAString,
pub application_name: LocalizedText,
pub application_type: ApplicationType,
pub gateway_server_uri: UAString,
pub discovery_profile_uri: UAString,
pub discovery_urls: Option<Vec<UAString, Global>>,
}Fields
application_uri: UAStringproduct_uri: UAStringapplication_name: LocalizedTextapplication_type: ApplicationTypegateway_server_uri: UAStringdiscovery_profile_uri: UAStringdiscovery_urls: Option<Vec<UAString, Global>>Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ApplicationDescription, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ApplicationDescription, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
Returns the “default value” for a type. Read more
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.