[−][src]Struct opcua_server::prelude::Array
An array is a vector of values with an optional number of dimensions. It is expected that the multi-dimensional array is valid, or it might not be encoded or decoded properly. The dimensions should match the number of values, or the array is invalid.
Fields
values: Vec<Variant>Values are stored sequentially
dimensions: Vec<u32>Multi dimension array which can contain any scalar type, all the same type. Nested arrays are rejected. Higher rank dimensions are serialized first. For example an array with dimensions [2,2,2] is written in this order - [0,0,0], [0,0,1], [0,1,0], [0,1,1], [1,0,0], [1,0,1], [1,1,0], [1,1,1].
Implementations
impl Array[src]
pub fn new_single<V>(values: V) -> Array where
V: Into<Vec<Variant>>, [src]
V: Into<Vec<Variant>>,
pub fn new_multi<V, D>(values: V, dimensions: D) -> Array where
D: Into<Vec<u32>>,
V: Into<Vec<Variant>>, [src]
D: Into<Vec<u32>>,
V: Into<Vec<Variant>>,
pub fn is_valid(&self) -> bool[src]
pub fn has_dimensions(&self) -> bool[src]
pub fn encoding_mask(&self) -> u8[src]