[][src]Struct opcua_server::prelude::AttributesMask

pub struct AttributesMask { /* fields omitted */ }

Implementations

impl AttributesMask[src]

pub const ACCESS_LEVEL: AttributesMask[src]

Indicates if the AccessLevel Attribute is set.

pub const ARRAY_DIMENSIONS: AttributesMask[src]

Indicates if the ArrayDimensions Attribute is set.

pub const CONTAINS_NO_LOOPS: AttributesMask[src]

Indicates if the ContainsNoLoops Attribute is set.

pub const DATA_TYPE: AttributesMask[src]

Indicates if the DataType Attribute is set.

pub const DESCRIPTION: AttributesMask[src]

Indicates if the Description Attribute is set.

pub const DISPLAY_NAME: AttributesMask[src]

Indicates if the DisplayName Attribute is set.

pub const EVENT_NOTIFIER: AttributesMask[src]

Indicates if the EventNotifier Attribute is set.

pub const EXECUTABLE: AttributesMask[src]

Indicates if the Executable Attribute is set.

pub const HISTORIZING: AttributesMask[src]

Indicates if the Historizing Attribute is set.

pub const INVERSE_NAME: AttributesMask[src]

Indicates if the InverseName Attribute is set.

pub const IS_ABSTRACT: AttributesMask[src]

Indicates if the IsAbstract Attribute is set.

pub const MINIMUM_SAMPLING_INTERVAL: AttributesMask[src]

Indicates if the MinimumSamplingInterval Attribute is set.

pub const SYMMETRIC: AttributesMask[src]

Indicates if the Symmetric Attribute is set.

pub const USER_ACCESS_LEVEL: AttributesMask[src]

Indicates if the UserAccessLevel Attribute is set.

pub const USER_EXECUTABLE: AttributesMask[src]

Indicates if the UserExecutable Attribute is set.

pub const USER_WRITE_MASK: AttributesMask[src]

Indicates if the UserWriteMask Attribute is set.

pub const VALUE_RANK: AttributesMask[src]

Indicates if the ValueRank Attribute is set.

pub const WRITE_MASK: AttributesMask[src]

Indicates if the WriteMask Attribute is set.

pub const VALUE: AttributesMask[src]

Indicates if the Value Attribute is set

pub const fn empty() -> AttributesMask[src]

Returns an empty set of flags

pub const fn all() -> AttributesMask[src]

Returns the set containing all flags.

pub const fn bits(&self) -> u32[src]

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<AttributesMask>[src]

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> AttributesMask[src]

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> AttributesMask[src]

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool[src]

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool[src]

Returns true if all flags are currently set.

pub const fn intersects(&self, other: AttributesMask) -> bool[src]

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: AttributesMask) -> bool[src]

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: AttributesMask)[src]

Inserts the specified flags in-place.

pub fn remove(&mut self, other: AttributesMask)[src]

Removes the specified flags in-place.

pub fn toggle(&mut self, other: AttributesMask)[src]

Toggles the specified flags in-place.

pub fn set(&mut self, other: AttributesMask, value: bool)[src]

Inserts or removes the specified flags depending on the passed value.