Struct opcua_server::prelude::ByteString [−][src]
A sequence of octets.
Fields
value: Option<Vec<u8, Global>>Implementations
Create a null string (not the same as an empty string)
Test if the string is null or empty
Creates a byte string from a Base64 encoded string
This function is meant for use with NumericRange. It creates a substring from this string from min up to and inclusive of max. Note that min must have an index within the string but max is allowed to be beyond the end in which case the remainder of the string is returned (see docs for NumericRange).