Struct opcua_server::prelude::CreateSessionRequest [−][src]
pub struct CreateSessionRequest {
pub request_header: RequestHeader,
pub client_description: ApplicationDescription,
pub server_uri: UAString,
pub endpoint_url: UAString,
pub session_name: UAString,
pub client_nonce: ByteString,
pub client_certificate: ByteString,
pub requested_session_timeout: f64,
pub max_response_message_size: u32,
}Fields
request_header: RequestHeaderclient_description: ApplicationDescriptionserver_uri: UAStringendpoint_url: UAStringsession_name: UAStringclient_nonce: ByteStringclient_certificate: ByteStringrequested_session_timeout: f64max_response_message_size: u32Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<CreateSessionRequest, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<CreateSessionRequest, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.