Struct opcua_server::prelude::DataSetReaderDataType [−][src]
pub struct DataSetReaderDataType {Show 17 fields
pub name: UAString,
pub enabled: bool,
pub publisher_id: Variant,
pub writer_group_id: u16,
pub data_set_writer_id: u16,
pub data_set_meta_data: DataSetMetaDataType,
pub data_set_field_content_mask: DataSetFieldContentMask,
pub message_receive_timeout: f64,
pub key_frame_count: u32,
pub header_layout_uri: UAString,
pub security_mode: MessageSecurityMode,
pub security_group_id: UAString,
pub security_key_services: Option<Vec<EndpointDescription, Global>>,
pub data_set_reader_properties: Option<Vec<KeyValuePair, Global>>,
pub transport_settings: ExtensionObject,
pub message_settings: ExtensionObject,
pub subscribed_data_set: ExtensionObject,
}Fields
name: UAStringenabled: boolpublisher_id: Variantwriter_group_id: u16data_set_writer_id: u16data_set_meta_data: DataSetMetaDataTypedata_set_field_content_mask: DataSetFieldContentMaskmessage_receive_timeout: f64key_frame_count: u32header_layout_uri: UAStringsecurity_mode: MessageSecurityModesecurity_group_id: UAStringsecurity_key_services: Option<Vec<EndpointDescription, Global>>data_set_reader_properties: Option<Vec<KeyValuePair, Global>>transport_settings: ExtensionObjectmessage_settings: ExtensionObjectsubscribed_data_set: ExtensionObjectTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<DataSetReaderDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<DataSetReaderDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.