Struct opcua_server::prelude::DataSetWriterDataType [−][src]
pub struct DataSetWriterDataType {
pub name: UAString,
pub enabled: bool,
pub data_set_writer_id: u16,
pub data_set_field_content_mask: DataSetFieldContentMask,
pub key_frame_count: u32,
pub data_set_name: UAString,
pub data_set_writer_properties: Option<Vec<KeyValuePair, Global>>,
pub transport_settings: ExtensionObject,
pub message_settings: ExtensionObject,
}Fields
name: UAStringenabled: booldata_set_writer_id: u16data_set_field_content_mask: DataSetFieldContentMaskkey_frame_count: u32data_set_name: UAStringdata_set_writer_properties: Option<Vec<KeyValuePair, Global>>transport_settings: ExtensionObjectmessage_settings: ExtensionObjectTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<DataSetWriterDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<DataSetWriterDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.