Struct opcua_server::prelude::DataTypeAttributes [−][src]
pub struct DataTypeAttributes {
pub specified_attributes: u32,
pub display_name: LocalizedText,
pub description: LocalizedText,
pub write_mask: u32,
pub user_write_mask: u32,
pub is_abstract: bool,
}Fields
specified_attributes: u32display_name: LocalizedTextdescription: LocalizedTextwrite_mask: u32user_write_mask: u32is_abstract: boolTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<DataTypeAttributes, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<DataTypeAttributes, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.