Struct opcua_server::prelude::EndpointConfiguration [−][src]
pub struct EndpointConfiguration {
pub operation_timeout: i32,
pub use_binary_encoding: bool,
pub max_string_length: i32,
pub max_byte_string_length: i32,
pub max_array_length: i32,
pub max_message_size: i32,
pub max_buffer_size: i32,
pub channel_lifetime: i32,
pub security_token_lifetime: i32,
}Fields
operation_timeout: i32use_binary_encoding: boolmax_string_length: i32max_byte_string_length: i32max_array_length: i32max_message_size: i32max_buffer_size: i32channel_lifetime: i32security_token_lifetime: i32Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<EndpointConfiguration, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<EndpointConfiguration, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.