Struct opcua_server::prelude::ExtensionObject [−][src]
pub struct ExtensionObject {
pub node_id: NodeId,
pub body: ExtensionObjectEncoding,
}Expand description
An extension object holds a serialized object identified by its node id.
Fields
node_id: NodeIdbody: ExtensionObjectEncodingImplementations
Creates a null extension object, i.e. one with no value or payload
Returns the object id of the thing this extension object contains, assuming the object id can be recognised from the node id.
pub fn from_encodable<N, T>(node_id: N, encodable: &T) -> ExtensionObject where
T: BinaryEncoder<T>,
N: Into<NodeId>,
pub fn from_encodable<N, T>(node_id: N, encodable: &T) -> ExtensionObject where
T: BinaryEncoder<T>,
N: Into<NodeId>,
Creates an extension object with the specified node id and the encodable object as its payload. The body is set to a byte string containing the encoded struct.
pub fn decode_inner<T>(
&self,
decoding_limits: &DecodingLimits
) -> Result<T, StatusCode> where
T: BinaryEncoder<T>,
pub fn decode_inner<T>(
&self,
decoding_limits: &DecodingLimits
) -> Result<T, StatusCode> where
T: BinaryEncoder<T>,
Decodes the inner content of the extension object and returns it. The node id is ignored for decoding. The caller supplies the binary encoder impl that should be used to extract the data. Errors result in a decoding error.