Struct opcua_server::prelude::FieldMetaData [−][src]
pub struct FieldMetaData {
pub name: UAString,
pub description: LocalizedText,
pub field_flags: DataSetFieldFlags,
pub built_in_type: u8,
pub data_type: NodeId,
pub value_rank: i32,
pub array_dimensions: Option<Vec<u32, Global>>,
pub max_string_length: u32,
pub data_set_field_id: Guid,
pub properties: Option<Vec<KeyValuePair, Global>>,
}Fields
name: UAStringdescription: LocalizedTextfield_flags: DataSetFieldFlagsbuilt_in_type: u8data_type: NodeIdvalue_rank: i32array_dimensions: Option<Vec<u32, Global>>max_string_length: u32data_set_field_id: Guidproperties: Option<Vec<KeyValuePair, Global>>Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<FieldMetaData, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<FieldMetaData, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.