Struct opcua_server::prelude::FieldTargetDataType [−][src]
pub struct FieldTargetDataType {
pub data_set_field_id: Guid,
pub receiver_index_range: UAString,
pub target_node_id: NodeId,
pub attribute_id: u32,
pub write_index_range: UAString,
pub override_value_handling: OverrideValueHandling,
pub override_value: Variant,
}Fields
data_set_field_id: Guidreceiver_index_range: UAStringtarget_node_id: NodeIdattribute_id: u32write_index_range: UAStringoverride_value_handling: OverrideValueHandlingoverride_value: VariantTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<FieldTargetDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<FieldTargetDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.