Struct opcua_server::prelude::ModifySubscriptionRequest [−][src]
pub struct ModifySubscriptionRequest {
pub request_header: RequestHeader,
pub subscription_id: u32,
pub requested_publishing_interval: f64,
pub requested_lifetime_count: u32,
pub requested_max_keep_alive_count: u32,
pub max_notifications_per_publish: u32,
pub priority: u8,
}Fields
request_header: RequestHeadersubscription_id: u32requested_publishing_interval: f64requested_lifetime_count: u32requested_max_keep_alive_count: u32max_notifications_per_publish: u32priority: u8Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ModifySubscriptionRequest, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ModifySubscriptionRequest, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.