Struct opcua_server::prelude::ModifySubscriptionResponse
source · [−]pub struct ModifySubscriptionResponse {
pub response_header: ResponseHeader,
pub revised_publishing_interval: f64,
pub revised_lifetime_count: u32,
pub revised_max_keep_alive_count: u32,
}Fields
response_header: ResponseHeaderrevised_publishing_interval: f64revised_lifetime_count: u32revised_max_keep_alive_count: u32Trait Implementations
sourceimpl BinaryEncoder<ModifySubscriptionResponse> for ModifySubscriptionResponse
impl BinaryEncoder<ModifySubscriptionResponse> for ModifySubscriptionResponse
sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
sourcefn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
fn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
Encodes the instance to the write stream.
sourcefn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<ModifySubscriptionResponse, StatusCode> where
S: Read,
fn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<ModifySubscriptionResponse, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a BadDecodingError as soon as possible. Read more
fn encode_to_vec(&self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
sourceimpl Clone for ModifySubscriptionResponse
impl Clone for ModifySubscriptionResponse
sourcefn clone(&self) -> ModifySubscriptionResponse
fn clone(&self) -> ModifySubscriptionResponse
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ModifySubscriptionResponse
impl Debug for ModifySubscriptionResponse
sourceimpl Into<SupportedMessage> for ModifySubscriptionResponse
impl Into<SupportedMessage> for ModifySubscriptionResponse
sourcefn into(self) -> SupportedMessage
fn into(self) -> SupportedMessage
Performs the conversion.
sourceimpl PartialEq<ModifySubscriptionResponse> for ModifySubscriptionResponse
impl PartialEq<ModifySubscriptionResponse> for ModifySubscriptionResponse
sourcefn eq(&self, other: &ModifySubscriptionResponse) -> bool
fn eq(&self, other: &ModifySubscriptionResponse) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ModifySubscriptionResponse) -> bool
fn ne(&self, other: &ModifySubscriptionResponse) -> bool
This method tests for !=.
impl StructuralPartialEq for ModifySubscriptionResponse