Struct opcua_server::prelude::NotificationMessage [−][src]
pub struct NotificationMessage {
pub sequence_number: u32,
pub publish_time: DateTime,
pub notification_data: Option<Vec<ExtensionObject, Global>>,
}Fields
sequence_number: u32publish_time: DateTimenotification_data: Option<Vec<ExtensionObject, Global>>Implementations
pub fn data_change(
sequence_number: u32,
publish_time: DateTime,
data_change_notifications: Vec<MonitoredItemNotification, Global>,
event_notifications: Vec<EventFieldList, Global>
) -> NotificationMessage
pub fn data_change(
sequence_number: u32,
publish_time: DateTime,
data_change_notifications: Vec<MonitoredItemNotification, Global>,
event_notifications: Vec<EventFieldList, Global>
) -> NotificationMessage
Create a notification message which contains data change AND / OR events. Calling this with neither will panic. Notification data can have up to 2 elements to covers the case in table 158 where a subscription contains monitored items for events and data.
pub fn status_change(
sequence_number: u32,
publish_time: DateTime,
status: StatusCode
) -> NotificationMessage
pub fn status_change(
sequence_number: u32,
publish_time: DateTime,
status: StatusCode
) -> NotificationMessage
Create a status change notification message
Create a keep-alive notification message
pub fn notifications(
&self,
decoding_limits: &DecodingLimits
) -> Option<(Vec<DataChangeNotification, Global>, Vec<EventNotificationList, Global>)>
pub fn notifications(
&self,
decoding_limits: &DecodingLimits
) -> Option<(Vec<DataChangeNotification, Global>, Vec<EventNotificationList, Global>)>
Extract notifications from the message. Unrecognized / unparseable notifications will be
ignored. If there are no notifications, the function will return None.