Struct opcua_server::prelude::OpenSecureChannelRequest
source · [−]pub struct OpenSecureChannelRequest {
pub request_header: RequestHeader,
pub client_protocol_version: u32,
pub request_type: SecurityTokenRequestType,
pub security_mode: MessageSecurityMode,
pub client_nonce: ByteString,
pub requested_lifetime: u32,
}Fields
request_header: RequestHeaderclient_protocol_version: u32request_type: SecurityTokenRequestTypesecurity_mode: MessageSecurityModeclient_nonce: ByteStringrequested_lifetime: u32Trait Implementations
sourceimpl BinaryEncoder<OpenSecureChannelRequest> for OpenSecureChannelRequest
impl BinaryEncoder<OpenSecureChannelRequest> for OpenSecureChannelRequest
sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
sourcefn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
fn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
Encodes the instance to the write stream.
sourcefn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<OpenSecureChannelRequest, StatusCode> where
S: Read,
fn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<OpenSecureChannelRequest, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a BadDecodingError as soon as possible. Read more
fn encode_to_vec(&self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
sourceimpl Clone for OpenSecureChannelRequest
impl Clone for OpenSecureChannelRequest
sourcefn clone(&self) -> OpenSecureChannelRequest
fn clone(&self) -> OpenSecureChannelRequest
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for OpenSecureChannelRequest
impl Debug for OpenSecureChannelRequest
sourceimpl Into<SupportedMessage> for OpenSecureChannelRequest
impl Into<SupportedMessage> for OpenSecureChannelRequest
sourcefn into(self) -> SupportedMessage
fn into(self) -> SupportedMessage
Performs the conversion.
sourceimpl PartialEq<OpenSecureChannelRequest> for OpenSecureChannelRequest
impl PartialEq<OpenSecureChannelRequest> for OpenSecureChannelRequest
sourcefn eq(&self, other: &OpenSecureChannelRequest) -> bool
fn eq(&self, other: &OpenSecureChannelRequest) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &OpenSecureChannelRequest) -> bool
fn ne(&self, other: &OpenSecureChannelRequest) -> bool
This method tests for !=.
impl StructuralPartialEq for OpenSecureChannelRequest