[][src]Struct opcua_server::prelude::PKey

pub struct PKey<T> { /* fields omitted */ }

This is a wrapper around an OpenSSL asymmetric key pair. Since openssl 0.10, the PKey is either a public or private key so we have to differentiate that as well.

Implementations

impl PKey<Private>[src]

pub fn new(bit_length: u32) -> PKey<Private>[src]

pub fn wrap_private_key(pkey: PKey<Private>) -> PKey<Private>[src]

pub fn from_pem(pem: &[u8]) -> Result<PKey<Private>, ()>[src]

pub fn private_key_to_pem(&self) -> Result<Vec<u8>, ()>[src]

pub fn sign_hmac_sha1(
    &self,
    data: &[u8],
    signature: &mut [u8]
) -> Result<usize, StatusCode>
[src]

Signs the data using RSA-SHA1

pub fn sign_hmac_sha256(
    &self,
    data: &[u8],
    signature: &mut [u8]
) -> Result<usize, StatusCode>
[src]

Signs the data using RSA-SHA256

pub fn sign_hmac_sha256_pss(
    &self,
    data: &[u8],
    signature: &mut [u8]
) -> Result<usize, StatusCode>
[src]

Signs the data using RSA-SHA256-PSS

pub fn private_decrypt(
    &self,
    src: &[u8],
    dst: &mut [u8],
    padding: RsaPadding
) -> Result<usize, ()>
[src]

Decrypts data in src to dst using the specified padding and returning the size of the decrypted data in bytes or an error.

impl PKey<Public>[src]

pub fn wrap_public_key(pkey: PKey<Public>) -> PKey<Public>[src]

pub fn verify_hmac_sha1(
    &self,
    data: &[u8],
    signature: &[u8]
) -> Result<bool, StatusCode>
[src]

Verifies the data using RSA-SHA1

pub fn verify_hmac_sha256(
    &self,
    data: &[u8],
    signature: &[u8]
) -> Result<bool, StatusCode>
[src]

Verifies the data using RSA-SHA256

pub fn verify_hmac_sha256_pss(
    &self,
    data: &[u8],
    signature: &[u8]
) -> Result<bool, StatusCode>
[src]

Verifies the data using RSA-SHA256-PSS

pub fn public_encrypt(
    &self,
    src: &[u8],
    dst: &mut [u8],
    padding: RsaPadding
) -> Result<usize, ()>
[src]

Encrypts data from src to dst using the specified padding and returns the size of encrypted data in bytes or an error.