Struct opcua_server::prelude::ProgramDiagnosticDataType [−][src]
pub struct ProgramDiagnosticDataType {
pub create_session_id: NodeId,
pub create_client_name: UAString,
pub invocation_creation_time: DateTime,
pub last_transition_time: DateTime,
pub last_method_call: UAString,
pub last_method_session_id: NodeId,
pub last_method_input_arguments: Option<Vec<Argument, Global>>,
pub last_method_output_arguments: Option<Vec<Argument, Global>>,
pub last_method_call_time: DateTime,
pub last_method_return_status: StatusResult,
}Fields
create_session_id: NodeIdcreate_client_name: UAStringinvocation_creation_time: DateTimelast_transition_time: DateTimelast_method_call: UAStringlast_method_session_id: NodeIdlast_method_input_arguments: Option<Vec<Argument, Global>>last_method_output_arguments: Option<Vec<Argument, Global>>last_method_call_time: DateTimelast_method_return_status: StatusResultTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ProgramDiagnosticDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ProgramDiagnosticDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.