Struct opcua_server::prelude::PubSubConnectionDataType [−][src]
pub struct PubSubConnectionDataType {
pub name: UAString,
pub enabled: bool,
pub publisher_id: Variant,
pub transport_profile_uri: UAString,
pub address: ExtensionObject,
pub connection_properties: Option<Vec<KeyValuePair, Global>>,
pub transport_settings: ExtensionObject,
pub writer_groups: Option<Vec<WriterGroupDataType, Global>>,
pub reader_groups: Option<Vec<ReaderGroupDataType, Global>>,
}Fields
name: UAStringenabled: boolpublisher_id: Varianttransport_profile_uri: UAStringaddress: ExtensionObjectconnection_properties: Option<Vec<KeyValuePair, Global>>transport_settings: ExtensionObjectwriter_groups: Option<Vec<WriterGroupDataType, Global>>reader_groups: Option<Vec<ReaderGroupDataType, Global>>Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<PubSubConnectionDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<PubSubConnectionDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.