Struct opcua_server::prelude::PublishedVariableDataType [−][src]
pub struct PublishedVariableDataType {
pub published_variable: NodeId,
pub attribute_id: u32,
pub sampling_interval_hint: f64,
pub deadband_type: u32,
pub deadband_value: f64,
pub index_range: UAString,
pub substitute_value: Variant,
pub meta_data_properties: Option<Vec<QualifiedName, Global>>,
}Fields
published_variable: NodeIdattribute_id: u32sampling_interval_hint: f64deadband_type: u32deadband_value: f64index_range: UAStringsubstitute_value: Variantmeta_data_properties: Option<Vec<QualifiedName, Global>>Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<PublishedVariableDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<PublishedVariableDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.