Struct opcua_server::prelude::QueryFirstResponse [−][src]
pub struct QueryFirstResponse {
pub response_header: ResponseHeader,
pub query_data_sets: Option<Vec<QueryDataSet, Global>>,
pub continuation_point: ByteString,
pub parsing_results: Option<Vec<ParsingResult, Global>>,
pub diagnostic_infos: Option<Vec<DiagnosticInfo, Global>>,
pub filter_result: ContentFilterResult,
}Fields
response_header: ResponseHeaderquery_data_sets: Option<Vec<QueryDataSet, Global>>continuation_point: ByteStringparsing_results: Option<Vec<ParsingResult, Global>>diagnostic_infos: Option<Vec<DiagnosticInfo, Global>>filter_result: ContentFilterResultTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<QueryFirstResponse, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<QueryFirstResponse, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.