Struct opcua_server::prelude::QueryNextRequest
source · [−]pub struct QueryNextRequest {
pub request_header: RequestHeader,
pub release_continuation_point: bool,
pub continuation_point: ByteString,
}Fields
request_header: RequestHeaderrelease_continuation_point: boolcontinuation_point: ByteStringTrait Implementations
sourceimpl BinaryEncoder<QueryNextRequest> for QueryNextRequest
impl BinaryEncoder<QueryNextRequest> for QueryNextRequest
sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
sourcefn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
fn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
Encodes the instance to the write stream.
sourcefn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<QueryNextRequest, StatusCode> where
S: Read,
fn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<QueryNextRequest, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a BadDecodingError as soon as possible. Read more
fn encode_to_vec(&self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
sourceimpl Clone for QueryNextRequest
impl Clone for QueryNextRequest
sourcefn clone(&self) -> QueryNextRequest
fn clone(&self) -> QueryNextRequest
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for QueryNextRequest
impl Debug for QueryNextRequest
sourceimpl Into<SupportedMessage> for QueryNextRequest
impl Into<SupportedMessage> for QueryNextRequest
sourcefn into(self) -> SupportedMessage
fn into(self) -> SupportedMessage
Performs the conversion.
sourceimpl MessageInfo for QueryNextRequest
impl MessageInfo for QueryNextRequest
sourceimpl PartialEq<QueryNextRequest> for QueryNextRequest
impl PartialEq<QueryNextRequest> for QueryNextRequest
sourcefn eq(&self, other: &QueryNextRequest) -> bool
fn eq(&self, other: &QueryNextRequest) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &QueryNextRequest) -> bool
fn ne(&self, other: &QueryNextRequest) -> bool
This method tests for !=.
impl StructuralPartialEq for QueryNextRequest