Struct opcua_server::prelude::ReaderGroupDataType [−][src]
pub struct ReaderGroupDataType {
pub name: UAString,
pub enabled: bool,
pub security_mode: MessageSecurityMode,
pub security_group_id: UAString,
pub security_key_services: Option<Vec<EndpointDescription, Global>>,
pub max_network_message_size: u32,
pub group_properties: Option<Vec<KeyValuePair, Global>>,
pub transport_settings: ExtensionObject,
pub message_settings: ExtensionObject,
pub data_set_readers: Option<Vec<DataSetReaderDataType, Global>>,
}Fields
name: UAStringenabled: boolsecurity_mode: MessageSecurityModesecurity_group_id: UAStringsecurity_key_services: Option<Vec<EndpointDescription, Global>>max_network_message_size: u32group_properties: Option<Vec<KeyValuePair, Global>>transport_settings: ExtensionObjectmessage_settings: ExtensionObjectdata_set_readers: Option<Vec<DataSetReaderDataType, Global>>Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ReaderGroupDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ReaderGroupDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.