Struct opcua_server::prelude::ReferenceDescription [−][src]
pub struct ReferenceDescription {
pub reference_type_id: NodeId,
pub is_forward: bool,
pub node_id: ExpandedNodeId,
pub browse_name: QualifiedName,
pub display_name: LocalizedText,
pub node_class: NodeClass,
pub type_definition: ExpandedNodeId,
}Fields
reference_type_id: NodeIdis_forward: boolnode_id: ExpandedNodeIdbrowse_name: QualifiedNamedisplay_name: LocalizedTextnode_class: NodeClasstype_definition: ExpandedNodeIdTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ReferenceDescription, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ReferenceDescription, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.