[][src]Struct opcua_server::prelude::RelativePath

pub struct RelativePath {
    pub elements: Option<Vec<RelativePathElement>>,
}

Fields

elements: Option<Vec<RelativePathElement>>

Implementations

impl RelativePath[src]

pub fn from_str<CB>(path: &str, node_resolver: &CB) -> Result<RelativePath, ()> where
    CB: Fn(u16, &str) -> Option<NodeId>, 
[src]

Converts a string into a relative path. Caller must supply a node_resolver which will be used to look up nodes from their browse name. The function will reject strings that look unusually long or contain too many elements.