Struct opcua_server::prelude::SessionDiagnosticsDataType [−][src]
pub struct SessionDiagnosticsDataType {Show 43 fields
pub session_id: NodeId,
pub session_name: UAString,
pub client_description: ApplicationDescription,
pub server_uri: UAString,
pub endpoint_url: UAString,
pub locale_ids: Option<Vec<UAString, Global>>,
pub actual_session_timeout: f64,
pub max_response_message_size: u32,
pub client_connection_time: DateTime,
pub client_last_contact_time: DateTime,
pub current_subscriptions_count: u32,
pub current_monitored_items_count: u32,
pub current_publish_requests_in_queue: u32,
pub total_request_count: ServiceCounterDataType,
pub unauthorized_request_count: u32,
pub read_count: ServiceCounterDataType,
pub history_read_count: ServiceCounterDataType,
pub write_count: ServiceCounterDataType,
pub history_update_count: ServiceCounterDataType,
pub call_count: ServiceCounterDataType,
pub create_monitored_items_count: ServiceCounterDataType,
pub modify_monitored_items_count: ServiceCounterDataType,
pub set_monitoring_mode_count: ServiceCounterDataType,
pub set_triggering_count: ServiceCounterDataType,
pub delete_monitored_items_count: ServiceCounterDataType,
pub create_subscription_count: ServiceCounterDataType,
pub modify_subscription_count: ServiceCounterDataType,
pub set_publishing_mode_count: ServiceCounterDataType,
pub publish_count: ServiceCounterDataType,
pub republish_count: ServiceCounterDataType,
pub transfer_subscriptions_count: ServiceCounterDataType,
pub delete_subscriptions_count: ServiceCounterDataType,
pub add_nodes_count: ServiceCounterDataType,
pub add_references_count: ServiceCounterDataType,
pub delete_nodes_count: ServiceCounterDataType,
pub delete_references_count: ServiceCounterDataType,
pub browse_count: ServiceCounterDataType,
pub browse_next_count: ServiceCounterDataType,
pub translate_browse_paths_to_node_ids_count: ServiceCounterDataType,
pub query_first_count: ServiceCounterDataType,
pub query_next_count: ServiceCounterDataType,
pub register_nodes_count: ServiceCounterDataType,
pub unregister_nodes_count: ServiceCounterDataType,
}Fields
session_id: NodeIdsession_name: UAStringclient_description: ApplicationDescriptionserver_uri: UAStringendpoint_url: UAStringlocale_ids: Option<Vec<UAString, Global>>actual_session_timeout: f64max_response_message_size: u32client_connection_time: DateTimeclient_last_contact_time: DateTimecurrent_subscriptions_count: u32current_monitored_items_count: u32current_publish_requests_in_queue: u32total_request_count: ServiceCounterDataTyperead_count: ServiceCounterDataTypehistory_read_count: ServiceCounterDataTypewrite_count: ServiceCounterDataTypehistory_update_count: ServiceCounterDataTypecall_count: ServiceCounterDataTypecreate_monitored_items_count: ServiceCounterDataTypemodify_monitored_items_count: ServiceCounterDataTypeset_monitoring_mode_count: ServiceCounterDataTypeset_triggering_count: ServiceCounterDataTypedelete_monitored_items_count: ServiceCounterDataTypecreate_subscription_count: ServiceCounterDataTypemodify_subscription_count: ServiceCounterDataTypeset_publishing_mode_count: ServiceCounterDataTypepublish_count: ServiceCounterDataTyperepublish_count: ServiceCounterDataTypetransfer_subscriptions_count: ServiceCounterDataTypedelete_subscriptions_count: ServiceCounterDataTypeadd_nodes_count: ServiceCounterDataTypeadd_references_count: ServiceCounterDataTypedelete_nodes_count: ServiceCounterDataTypedelete_references_count: ServiceCounterDataTypebrowse_count: ServiceCounterDataTypebrowse_next_count: ServiceCounterDataTypetranslate_browse_paths_to_node_ids_count: ServiceCounterDataTypequery_first_count: ServiceCounterDataTypequery_next_count: ServiceCounterDataTyperegister_nodes_count: ServiceCounterDataTypeunregister_nodes_count: ServiceCounterDataTypeTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<SessionDiagnosticsDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<SessionDiagnosticsDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.