Struct opcua_server::prelude::SessionSecurityDiagnosticsDataType [−][src]
pub struct SessionSecurityDiagnosticsDataType {
pub session_id: NodeId,
pub client_user_id_of_session: UAString,
pub client_user_id_history: Option<Vec<UAString, Global>>,
pub authentication_mechanism: UAString,
pub encoding: UAString,
pub transport_protocol: UAString,
pub security_mode: MessageSecurityMode,
pub security_policy_uri: UAString,
pub client_certificate: ByteString,
}Fields
session_id: NodeIdclient_user_id_of_session: UAStringclient_user_id_history: Option<Vec<UAString, Global>>authentication_mechanism: UAStringencoding: UAStringtransport_protocol: UAStringsecurity_mode: MessageSecurityModesecurity_policy_uri: UAStringclient_certificate: ByteStringTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<SessionSecurityDiagnosticsDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<SessionSecurityDiagnosticsDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.