Struct opcua_server::prelude::SimpleTypeDescription [−][src]
pub struct SimpleTypeDescription {
pub data_type_id: NodeId,
pub name: QualifiedName,
pub base_data_type: NodeId,
pub built_in_type: u8,
}Fields
data_type_id: NodeIdname: QualifiedNamebase_data_type: NodeIdbuilt_in_type: u8Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<SimpleTypeDescription, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<SimpleTypeDescription, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.