[][src]Struct opcua_server::prelude::UAString

pub struct UAString { /* fields omitted */ }

To avoid naming conflict hell, the OPC UA String type is typed UAString so it does not collide with the Rust String.

A string contains UTF-8 encoded characters or a null value. A null value is distinct from being an empty string so internally, the code maintains that distinction by holding the value as an Option<String>.

Implementations

impl UAString[src]

pub fn value(&self) -> &Option<String>[src]

pub fn set_value(&mut self, value: Option<String>)[src]

pub fn is_empty(&self) -> bool[src]

Returns true if the string is null or empty, false otherwise

pub fn len(&self) -> isize[src]

Returns the length of the string in bytes or -1 for null.

pub fn null() -> UAString[src]

Create a null string (not the same as an empty string).

pub fn is_null(&self) -> bool[src]

Test if the string is null.

pub fn substring(&self, min: usize, max: usize) -> Result<UAString, ()>[src]

This function is meant for use with NumericRange. It creates a substring from this string from min up to and inclusive of max. Note that min must have an index within the string but max is allowed to be beyond the end in which case the remainder of the string is returned (see docs for NumericRange).