Struct opcua_server::prelude::UadpDataSetReaderMessageDataType [−][src]
pub struct UadpDataSetReaderMessageDataType {
pub group_version: u32,
pub network_message_number: u16,
pub data_set_offset: u16,
pub data_set_class_id: Guid,
pub network_message_content_mask: UadpNetworkMessageContentMask,
pub data_set_message_content_mask: UadpDataSetMessageContentMask,
pub publishing_interval: f64,
pub receive_offset: f64,
pub processing_offset: f64,
}Fields
group_version: u32network_message_number: u16data_set_offset: u16data_set_class_id: Guidnetwork_message_content_mask: UadpNetworkMessageContentMaskdata_set_message_content_mask: UadpDataSetMessageContentMaskpublishing_interval: f64receive_offset: f64processing_offset: f64Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<UadpDataSetReaderMessageDataType, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<UadpDataSetReaderMessageDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.