Struct opcua_server::prelude::VariableAttributes [−][src]
pub struct VariableAttributes {Show 13 fields
pub specified_attributes: u32,
pub display_name: LocalizedText,
pub description: LocalizedText,
pub write_mask: u32,
pub user_write_mask: u32,
pub value: Variant,
pub data_type: NodeId,
pub value_rank: i32,
pub array_dimensions: Option<Vec<u32, Global>>,
pub access_level: u8,
pub user_access_level: u8,
pub minimum_sampling_interval: f64,
pub historizing: bool,
}Fields
specified_attributes: u32display_name: LocalizedTextdescription: LocalizedTextwrite_mask: u32user_write_mask: u32value: Variantdata_type: NodeIdvalue_rank: i32array_dimensions: Option<Vec<u32, Global>>access_level: u8user_access_level: u8minimum_sampling_interval: f64historizing: boolTrait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<VariableAttributes, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<VariableAttributes, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.