Struct opcua_server::prelude::ViewAttributes
source · [−]pub struct ViewAttributes {
pub specified_attributes: u32,
pub display_name: LocalizedText,
pub description: LocalizedText,
pub write_mask: u32,
pub user_write_mask: u32,
pub contains_no_loops: bool,
pub event_notifier: u8,
}Fields
specified_attributes: u32display_name: LocalizedTextdescription: LocalizedTextwrite_mask: u32user_write_mask: u32contains_no_loops: boolevent_notifier: u8Trait Implementations
sourceimpl BinaryEncoder<ViewAttributes> for ViewAttributes
impl BinaryEncoder<ViewAttributes> for ViewAttributes
sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
sourcefn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
fn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
Encodes the instance to the write stream.
sourcefn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<ViewAttributes, StatusCode> where
S: Read,
fn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<ViewAttributes, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a BadDecodingError as soon as possible. Read more
fn encode_to_vec(&self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
sourceimpl Clone for ViewAttributes
impl Clone for ViewAttributes
sourcefn clone(&self) -> ViewAttributes
fn clone(&self) -> ViewAttributes
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for ViewAttributes
impl Debug for ViewAttributes
sourceimpl PartialEq<ViewAttributes> for ViewAttributes
impl PartialEq<ViewAttributes> for ViewAttributes
sourcefn eq(&self, other: &ViewAttributes) -> bool
fn eq(&self, other: &ViewAttributes) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ViewAttributes) -> bool
fn ne(&self, other: &ViewAttributes) -> bool
This method tests for !=.
impl StructuralPartialEq for ViewAttributes