[][src]Struct opcua_server::prelude::WriteMask

pub struct WriteMask { /* fields omitted */ }

Implementations

impl WriteMask[src]

pub const ACCESS_LEVEL: WriteMask[src]

Indicates if the AccessLevel Attribute is writable.

pub const ARRAY_DIMENSIONS: WriteMask[src]

Indicates if the ArrayDimensions Attribute is writable.

pub const BROWSE_NAME: WriteMask[src]

Indicates if the BrowseName Attribute is writable.

pub const CONTAINS_NO_LOOPS: WriteMask[src]

Indicates if the ContainsNoLoops Attribute is writable.

pub const DATA_TYPE: WriteMask[src]

Indicates if the DataType Attribute is writable.

pub const DESCRIPTION: WriteMask[src]

Indicates if the Description Attribute is writable.

pub const DISPLAY_NAME: WriteMask[src]

Indicates if the DisplayName Attribute is writable.

pub const EVENT_NOTIFIER: WriteMask[src]

Indicates if the EventNotifier Attribute is writable.

pub const EXECUTABLE: WriteMask[src]

Indicates if the Executable Attribute is writable.

pub const HISTORIZING: WriteMask[src]

Indicates if the Historizing Attribute is writable.

pub const INVERSE_NAME: WriteMask[src]

Indicates if the InverseName Attribute is writable.

pub const IS_ABSTRACT: WriteMask[src]

Indicates if the IsAbstract Attribute is writable.

pub const MINIMUM_SAMPLING_INTERVAL: WriteMask[src]

Indicates if the MinimumSamplingInterval Attribute is writable.

pub const NODE_CLASS: WriteMask[src]

Indicates if the NodeClass Attribute is writable.

pub const NODE_ID: WriteMask[src]

Indicates if the NodeId Attribute is writable.

pub const SYMMETRIC: WriteMask[src]

Indicates if the Symmetric Attribute is writable.

pub const USER_ACCESS_LEVEL: WriteMask[src]

Indicates if the UserAccessLevel Attribute is writable.

pub const USER_EXECUTABLE: WriteMask[src]

Indicates if the UserExecutable Attribute is writable.

pub const USER_WRITE_MASK: WriteMask[src]

Indicates if the UserWriteMask Attribute is writable.

pub const VALUE_RANK: WriteMask[src]

Indicates if the ValueRank Attribute is writable.

pub const WRITE_MASK: WriteMask[src]

Indicates if the WriteMask Attribute is writable.

pub const VALUE_FOR_VARIABLE_TYPE: WriteMask[src]

Indicates if the Value Attribute is writable for a VariableType. It does not apply for Variables since this is handled by the AccessLevel and UserAccessLevel Attributes for the Variable. For Variables this bit shall be set to 0.

pub const DATA_TYPE_DEFINITION: WriteMask[src]

Indicates if the DataTypeDefinition Attribute is writable.

pub const ROLE_PERMISSIONS: WriteMask[src]

Indicates if the RolePermissions Attribute is writable.

pub const ACCESS_RESTRICTIONS: WriteMask[src]

Indicates if the AccessRestrictions Attribute is writable

pub const ACCESS_LEVEL_EX: WriteMask[src]

Indicates if the AccessLevelEx Attribute is writable

pub const fn empty() -> WriteMask[src]

Returns an empty set of flags

pub const fn all() -> WriteMask[src]

Returns the set containing all flags.

pub const fn bits(&self) -> u32[src]

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<WriteMask>[src]

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> WriteMask[src]

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const unsafe fn from_bits_unchecked(bits: u32) -> WriteMask[src]

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

pub const fn is_empty(&self) -> bool[src]

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool[src]

Returns true if all flags are currently set.

pub const fn intersects(&self, other: WriteMask) -> bool[src]

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: WriteMask) -> bool[src]

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: WriteMask)[src]

Inserts the specified flags in-place.

pub fn remove(&mut self, other: WriteMask)[src]

Removes the specified flags in-place.

pub fn toggle(&mut self, other: WriteMask)[src]

Toggles the specified flags in-place.

pub fn set(&mut self, other: WriteMask, value: bool)[src]

Inserts or removes the specified flags depending on the passed value.