Struct opcua_server::prelude::WriterGroupDataType
source · [−]pub struct WriterGroupDataType {Show 16 fields
pub name: UAString,
pub enabled: bool,
pub security_mode: MessageSecurityMode,
pub security_group_id: UAString,
pub security_key_services: Option<Vec<EndpointDescription, Global>>,
pub max_network_message_size: u32,
pub group_properties: Option<Vec<KeyValuePair, Global>>,
pub writer_group_id: u16,
pub publishing_interval: f64,
pub keep_alive_time: f64,
pub priority: u8,
pub locale_ids: Option<Vec<UAString, Global>>,
pub header_layout_uri: UAString,
pub transport_settings: ExtensionObject,
pub message_settings: ExtensionObject,
pub data_set_writers: Option<Vec<DataSetWriterDataType, Global>>,
}Fields
name: UAStringenabled: boolsecurity_mode: MessageSecurityModesecurity_group_id: UAStringsecurity_key_services: Option<Vec<EndpointDescription, Global>>max_network_message_size: u32group_properties: Option<Vec<KeyValuePair, Global>>writer_group_id: u16publishing_interval: f64keep_alive_time: f64priority: u8locale_ids: Option<Vec<UAString, Global>>header_layout_uri: UAStringtransport_settings: ExtensionObjectmessage_settings: ExtensionObjectdata_set_writers: Option<Vec<DataSetWriterDataType, Global>>Trait Implementations
sourceimpl BinaryEncoder<WriterGroupDataType> for WriterGroupDataType
impl BinaryEncoder<WriterGroupDataType> for WriterGroupDataType
sourcefn byte_len(&self) -> usize
fn byte_len(&self) -> usize
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
sourcefn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
fn encode<S>(&self, stream: &mut S) -> Result<usize, StatusCode> where
S: Write,
Encodes the instance to the write stream.
sourcefn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<WriterGroupDataType, StatusCode> where
S: Read,
fn decode<S>(
stream: &mut S,
decoding_options: &DecodingOptions
) -> Result<WriterGroupDataType, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding options contains restrictions set by
the server / client on the length of strings, arrays etc. If these limits are exceeded the
implementation should return with a BadDecodingError as soon as possible. Read more
fn encode_to_vec(&self) -> Vec<u8, Global>ⓘNotable traits for Vec<u8, A>impl<A> Write for Vec<u8, A> where
A: Allocator,
A: Allocator,
sourceimpl Clone for WriterGroupDataType
impl Clone for WriterGroupDataType
sourcefn clone(&self) -> WriterGroupDataType
fn clone(&self) -> WriterGroupDataType
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for WriterGroupDataType
impl Debug for WriterGroupDataType
sourceimpl PartialEq<WriterGroupDataType> for WriterGroupDataType
impl PartialEq<WriterGroupDataType> for WriterGroupDataType
sourcefn eq(&self, other: &WriterGroupDataType) -> bool
fn eq(&self, other: &WriterGroupDataType) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &WriterGroupDataType) -> bool
fn ne(&self, other: &WriterGroupDataType) -> bool
This method tests for !=.
impl StructuralPartialEq for WriterGroupDataType