Struct opcua_server::server::Server [−][src]
pub struct Server { /* fields omitted */ }Expand description
A Server represents a running instance of an OPC UA server. There can be more than one Server
running at any given time providing they do not share the same ports.
A Server is initialised from a ServerConfig. The ServerConfig sets what port the server
runs on, the endpoints it supports, the identity tokens it supports, identity tokens and so forth.
A single server can offer multiple endpoints with different security policies. A server can
also be configured to register itself with a discovery server.
Once the Server is configured, it is run by calling run which consumes the Server.
Alternatively if you have reason to maintain access to the server object,
you may call the static function run_server providing the server wrapped as
Arc<RwLock<Server>>.
The server’s AddressSpace is initialised with the default OPC UA node set, but may also
be extended with additional nodes representing folders, variables, methods etc.
The server’s CertificateStore manages the server’s private key and public certificate. It
also manages public certificates of incoming clients and arranges them into trusted and rejected
collections.
Implementations
Creates a new Server instance, initialising it from a ServerConfig.
Runs the server and blocks until it completes either by aborting or by error. Typically a server should be run on its own thread.
Calling this function consumes the server.
Runs the supplied server and blocks until it completes either by aborting or by error.
Returns the current ServerState for the server.
Returns the CertificateStore for the server.
Returns the AddressSpace for the server.
Returns the Connections for the server.
Returns the ServerMetrics for the server.
Sets a flag telling the running server to abort. The abort will happen asynchronously after all sessions have disconnected.
Creates a polling action that happens continuously on an interval while the server is running. For example, a server might run a polling action every 100ms to synchronous address space state between variables and their physical backends.
The function that is supplied does not take any arguments. It is expected that the implementation will move any variables into the function that are required to perform its action.
Create a new transport.