[][src]Struct opcua_server::session::Session

pub struct Session { /* fields omitted */ }

The Session is any state maintained between the client and server

Implementations

impl Session[src]

pub fn new(server: &Server) -> Session[src]

Create a Session from a Server

pub fn secure_channel(&self) -> Arc<RwLock<SecureChannel>>[src]

pub fn session_id(&self) -> &NodeId[src]

pub fn set_activated(&mut self, activated: bool)[src]

pub fn is_activated(&self) -> bool[src]

pub fn is_terminated(&self) -> bool[src]

pub fn terminated_at(&self) -> DateTimeUtc[src]

pub fn set_terminated(&mut self)[src]

pub fn authentication_token(&self) -> &NodeId[src]

pub fn set_authentication_token(&mut self, authentication_token: NodeId)[src]

pub fn session_timeout(&self) -> f64[src]

pub fn set_session_timeout(&mut self, session_timeout: f64)[src]

pub fn set_max_request_message_size(&mut self, max_request_message_size: u32)[src]

pub fn set_max_response_message_size(&mut self, max_response_message_size: u32)[src]

pub fn endpoint_url(&self) -> &UAString[src]

pub fn set_endpoint_url(&mut self, endpoint_url: UAString)[src]

pub fn set_security_policy_uri(&mut self, security_policy_uri: &str)[src]

pub fn set_user_identity(&mut self, user_identity: IdentityToken)[src]

pub fn last_service_request_timestamp(&self) -> DateTimeUtc[src]

pub fn set_last_service_request_timestamp(
    &mut self,
    last_service_request_timestamp: DateTimeUtc
)
[src]

pub fn locale_ids(&self) -> &Option<Vec<UAString>>[src]

pub fn set_locale_ids(&mut self, locale_ids: Option<Vec<UAString>>)[src]

pub fn client_certificate(&self) -> &Option<X509>[src]

pub fn set_client_certificate(&mut self, client_certificate: Option<X509>)[src]

pub fn session_nonce(&self) -> &ByteString[src]

pub fn set_session_nonce(&mut self, session_nonce: ByteString)[src]

pub fn session_name(&self) -> &UAString[src]

pub fn set_session_name(&mut self, session_name: UAString)[src]

pub fn client_user_id(&self) -> UAString[src]

Helper function to return the client user id from the identity token or None of there is no user id

This conforms to OPC Part 5 6.4.3 ClientUserId

pub fn secure_channel_id(&self) -> String[src]

Helper function to return the secure channel id as a string

pub fn is_session_terminated(&self) -> bool[src]

pub fn terminate_session(&mut self)[src]