pub struct SessionManager {
    pub sessions: HashMap<NodeId, Arc<RwLock<Session>>>,
    pub sessions_terminated: bool,
}

Fields

sessions: HashMap<NodeId, Arc<RwLock<Session>>>sessions_terminated: bool

Implementations

Puts all sessions into a terminated state and clears the map

Find a session by its session id and return it.

Finds the session by its authentication token and returns it. The authentication token can be renewed so it is not used as a key.

Register the session in the map so it can be searched on

Deregisters a session from the map