pub struct HistoryServerCapabilities {Show 16 fields
pub access_history_data: bool,
pub access_history_events: bool,
pub delete_at_time: bool,
pub delete_event: bool,
pub delete_raw: bool,
pub insert_annotation: bool,
pub insert_data: bool,
pub insert_event: bool,
pub max_return_data_values: u32,
pub max_return_event_values: u32,
pub replace_data: bool,
pub replace_event: bool,
pub server_timestamp_supported: bool,
pub update_data: bool,
pub update_event: bool,
pub aggregates: Vec<NodeId>,
}Expand description
History capabilities. As all history is implemented by custom node managers, this should be set according to what your node managers support.
Fields
access_history_data: boolAble to read historical data.
access_history_events: boolAble to read historical events.
delete_at_time: boolAble to delete data at a specific time.
delete_event: boolAble to delete events.
delete_raw: boolAble to delete raw data values.
insert_annotation: boolAble to insert history annotations.
insert_data: boolAble to insert historical data values.
insert_event: boolAble to insert historical events.
max_return_data_values: u32Maximum number of data values returned per history read request.
max_return_event_values: u32Maximum number of events returned per history read requset.
replace_data: boolAble to replace historical data values.
replace_event: boolAble to replace historical events.
server_timestamp_supported: boolStores the time historical data arrived at the server, as well as its original timestamp.
update_data: boolAble to update historical data.
update_event: boolAble to update historical events.
aggregates: Vec<NodeId>Supported history aggregates