pub struct Subscription { /* private fields */ }

Implementations

Creates monitored items on the specified subscription, returning the creation results

Modify the specified monitored items, returning a result for each

Sets the monitoring mode on one monitored item

Delete the specified monitored items (by item id), returning a status code for each

Sets the resend data flag which means the next publish request will receive the latest value of every monitored item whether it has changed in this cycle or not.

Reset the keep-alive counter to the maximum keep-alive count of the Subscription. The maximum keep-alive count is set by the Client when the Subscription is created and may be modified using the ModifySubscription Service

Reset the lifetime counter to the value specified for the life time of the subscription in the create subscription service

Start or restart the publishing timer and decrement the LifetimeCounter Variable.