Struct opcua_server::util::PollingAction
source · pub struct PollingAction {}Expand description
This is a convenience for a polling action. This struct starts a repeating timer that calls an action repeatedly.
pub struct PollingAction {}This is a convenience for a polling action. This struct starts a repeating timer that calls an action repeatedly.