Trait opcua_server::address_space::node::Node
source · pub trait Node {
fn node_class(&self) -> NodeClass;
fn node_id(&self) -> NodeId;
fn browse_name(&self) -> QualifiedName;
fn display_name(&self) -> LocalizedText;
fn description(&self) -> Option<LocalizedText>;
fn write_mask(&self) -> Option<WriteMask>;
fn set_write_mask(&mut self, write_mask: WriteMask);
fn user_write_mask(&self) -> Option<WriteMask>;
fn set_user_write_mask(&mut self, write_mask: WriteMask);
fn find_attribute(&self, attribute_id: AttributeId) -> Option<DataValue>;
fn set_attribute(
&mut self,
attribute_id: AttributeId,
value: DataValue
) -> Result<(), StatusCode>;
}Expand description
Implemented by Base and all derived Node types. Functions that return a result in an Option do so because the attribute is optional and not necessarily there.