[−][src]Trait opcua_server::address_space::node::NodeBase
Implemented within a macro for all Node types. Functions that return a result in an Option do so because the attribute is optional and not necessarily there.
Required methods
fn node_class(&self) -> NodeClass
Returns the node class - Object, ObjectType, Method, DataType, ReferenceType, Variable, VariableType or View
fn node_id(&self) -> NodeId
Returns the node's NodeId
fn browse_name(&self) -> QualifiedName
Returns the node's browse name
fn display_name(&self) -> LocalizedText
Returns the node's display name
fn set_display_name(&mut self, display_name: LocalizedText)
Sets the node's display name