pub struct VariableBuilder { /* private fields */ }
This is a builder object for constructing variable nodes programmatically.

Implementations

Yields the built variable. This function will panic if the variable is invalid.