pub struct VariableBuilder { /* private fields */ }
This is a builder object for constructing variable nodes programmatically.
Yields the built variable. This function will panic if the variable is invalid.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.