pub struct ServerBuilder { /* private fields */ }
The ServerBuilder is a builder for producing a Server. It is an alternative to constructing a ServerConfig from file or from scratch.

Implementations

Creates a simple endpoint that accepts anonymous connections

Sample mode turns on everything including a hard coded user/pass

Yields a [Client] from the values set by the builder. If the builder is not in a valid state it will return None.

Yields a [ClientConfig] from the values set by the builder.

Sets the application name.

Sets the application uri

Sets the product uri.

Sets whether the client should generate its own key pair if there is none found in the pki directory.

Sets the pki directory where client’s own key pair is stored and where /trusted and /rejected server certificates are stored.

Adds an endpoint to the list of endpoints the client knows of.

Adds multiple endpoints to the list of endpoints the client knows of.

Adds a user token to the server.

Sets the discovery server url that this server shall attempt to register itself with.

Sets the hostname and port to listen on

Discovery endpoint url - the url of this server used by clients to get endpoints.

Maximum number of subscriptions in a session

Max array length in elements

Max string length in characters

Max bytestring length in bytes