[−][src]Struct opcua_server::config::ServerConfig
Fields
application_name: StringAn id for this server
application_uri: StringA description for this server
product_uri: StringProduct url
pki_dir: PathBufpki folder, either absolute or relative to executable
create_sample_keypair: boolAutocreates public / private keypair if they don't exist. For testing/samples only since you do not have control of the values
trust_client_certs: boolAuto trusts client certificates. For testing/samples only unless you're sure what you're doing.
discovery_server_url: Option<String>Url to a discovery server - adding this string causes the server to assume you wish to register the server with a discovery server.
tcp_config: TcpConfigtcp configuration information
limits: ServerLimitsServer limits
locale_ids: Vec<String>Supported locale ids
user_tokens: BTreeMap<String, ServerUserToken>User tokens
discovery_urls: Vec<String>discovery endpoint url which may or may not be the same as the service endpoints below.
default_endpoint: Option<String>Default endpoint id
endpoints: BTreeMap<String, ServerEndpoint>Endpoints supported by the server
Implementations
impl ServerConfig[src]
pub fn new<T>(
application_name: T,
user_tokens: BTreeMap<String, ServerUserToken>,
endpoints: BTreeMap<String, ServerEndpoint>
) -> Self where
T: Into<String>, [src]
application_name: T,
user_tokens: BTreeMap<String, ServerUserToken>,
endpoints: BTreeMap<String, ServerEndpoint>
) -> Self where
T: Into<String>,
pub fn decoding_limits(&self) -> DecodingLimits[src]
pub fn add_endpoint(&mut self, id: &str, endpoint: ServerEndpoint)[src]
pub fn read_x509_thumbprints(&mut self)[src]
pub fn base_endpoint_url(&self) -> String[src]
Returns a opc.tcp://server:port url that paths can be appended onto
pub fn default_endpoint(&self) -> Option<&ServerEndpoint>[src]
Find the default endpoint
pub fn find_endpoint(
&self,
endpoint_url: &str,
security_policy: SecurityPolicy,
security_mode: MessageSecurityMode
) -> Option<&ServerEndpoint>[src]
&self,
endpoint_url: &str,
security_policy: SecurityPolicy,
security_mode: MessageSecurityMode
) -> Option<&ServerEndpoint>
Find the first endpoint that matches the specified url, security policy and message security mode.