[−][src]Struct opcua_server::config::ServerConfig
Fields
application_name: StringAn id for this server
application_uri: StringA description for this server
product_uri: StringProduct url
pki_dir: PathBufpki folder, either absolute or relative to executable
create_sample_keypair: boolAutocreates public / private keypair if they don't exist. For testing/samples only since you do not have control of the values
trust_client_certs: boolAuto trusts client certificates. For testing/samples only unless you're sure what you're doing.
discovery_server_url: Option<String>Url to a discovery server - adding this string causes the server to assume you wish to register the server with a discovery server.
tcp_config: TcpConfigtcp configuration information
user_tokens: BTreeMap<String, ServerUserToken>User tokens
discovery_urls: Vec<String>discovery endpoint url which may or may not be the same as the service endpoints below.
endpoints: BTreeMap<String, ServerEndpoint>Endpoints supported by the server
max_subscriptions: u32Maximum number of subscriptions in a session
max_array_length: u32Max array length in elements
max_string_length: u32Max string length in characters
max_byte_string_length: u32Max bytestring length in bytes
clients_can_modify_address_space: boolIndicates if clients are able to modify the address space through the node management service
set. This is a very broad flag and is likely to require more fine grained per user control
in a later revision. By default, this value is false
Methods
impl ServerConfig[src]
pub fn new<T>(
application_name: T,
user_tokens: BTreeMap<String, ServerUserToken>,
endpoints: BTreeMap<String, ServerEndpoint>
) -> Self where
T: Into<String>, [src]
application_name: T,
user_tokens: BTreeMap<String, ServerUserToken>,
endpoints: BTreeMap<String, ServerEndpoint>
) -> Self where
T: Into<String>,
pub fn decoding_limits(&self) -> DecodingLimits[src]
pub fn add_endpoint(&mut self, id: &str, endpoint: ServerEndpoint)[src]
pub fn base_endpoint_url(&self) -> String[src]
Returns a opc.tcp://server:port url that paths can be appended onto
pub fn find_endpoint(
&self,
endpoint_url: &str,
security_policy: SecurityPolicy,
security_mode: MessageSecurityMode
) -> Option<&ServerEndpoint>[src]
&self,
endpoint_url: &str,
security_policy: SecurityPolicy,
security_mode: MessageSecurityMode
) -> Option<&ServerEndpoint>
Find the first endpoint that matches the specified url, security policy and message security mode.