pub struct ServerConfig {
Show 14 fields pub application_name: String, pub application_uri: String, pub product_uri: String, pub pki_dir: PathBuf, pub create_sample_keypair: bool, pub discovery_server_url: Option<String>, pub tcp_config: TcpConfig, pub user_tokens: BTreeMap<String, ServerUserToken>, pub discovery_url: String, pub endpoints: BTreeMap<String, ServerEndpoint>, pub max_subscriptions: u32, pub max_array_length: u32, pub max_string_length: u32, pub max_byte_string_length: u32,
}

Fields

application_name: String

An id for this server

application_uri: String

A description for this server

product_uri: String

Product url

pki_dir: PathBuf

pki folder, either absolute or relative to executable

create_sample_keypair: bool

Autocreates public / private keypair if they don’t exist. For testing/samples only since you do not have control of the values

discovery_server_url: Option<String>

Url to a discovery server - adding this string causes the server to assume you wish to register the server with a discovery server.

tcp_config: TcpConfig

tcp configuration information

user_tokens: BTreeMap<String, ServerUserToken>

User tokens

discovery_url: String

discovery endpoint url which may or may not be the same as the service endpoints below.

endpoints: BTreeMap<String, ServerEndpoint>

Endpoints supported by the server

max_subscriptions: u32

Maximum number of subscriptions in a session

max_array_length: u32

Max array length in elements

max_string_length: u32

Max string length in characters

max_byte_string_length: u32

Max bytestring length in bytes

Implementations

Returns a opc.tcp://server:port url that paths can be appended onto

Find the first endpoint that matches the specified url, security policy and message security mode.