Struct opcua_server::config::ServerEndpoint [−][src]
pub struct ServerEndpoint {
pub path: String,
pub security_policy: String,
pub security_mode: String,
pub security_level: u8,
pub password_security_policy: Option<String>,
pub user_token_ids: BTreeSet<String>,
}Fields
path: StringEndpoint path
security_policy: StringSecurity policy
security_mode: StringSecurity mode
security_level: u8Security level, higher being more secure
password_security_policy: Option<String>Password security policy when a client supplies a user name identity token
user_token_ids: BTreeSet<String>User tokens
Implementations
pub fn new<T>(
path: T,
security_policy: SecurityPolicy,
security_mode: MessageSecurityMode,
user_token_ids: &[String]
) -> Self where
T: Into<String>,
pub fn new_basic128rsa15_sign_encrypt<T>(
path: T,
user_token_ids: &[String]
) -> Self where
T: Into<String>,
pub fn new_basic256_sign_encrypt<T>(path: T, user_token_ids: &[String]) -> Self where
T: Into<String>,
pub fn new_basic256sha256_sign<T>(path: T, user_token_ids: &[String]) -> Self where
T: Into<String>,
pub fn new_basic256sha256_sign_encrypt<T>(
path: T,
user_token_ids: &[String]
) -> Self where
T: Into<String>,
pub fn new_aes128_sha256_rsaoaep_sign<T>(
path: T,
user_token_ids: &[String]
) -> Self where
T: Into<String>,
pub fn new_aes128_sha256_rsaoaep_sign_encrypt<T>(
path: T,
user_token_ids: &[String]
) -> Self where
T: Into<String>,
pub fn new_aes256_sha256_rsapss_sign<T>(
path: T,
user_token_ids: &[String]
) -> Self where
T: Into<String>,
pub fn new_aes256_sha256_rsapss_sign_encrypt<T>(
path: T,
user_token_ids: &[String]
) -> Self where
T: Into<String>,
Returns the effective password security policy for the endpoint. This is the explicitly set password security policy, or just the regular security policy.
Test if the endpoint supports anonymous users
Tests if this endpoint supports user pass tokens. It does this by looking to see if any of the users allowed to access this endpoint are user pass users.
Tests if this endpoint supports x509 tokens. It does this by looking to see if any of the users allowed to access this endpoint are x509 users.