[][src]Struct opcua_server::config::ServerLimits

pub struct ServerLimits {
    pub clients_can_modify_address_space: bool,
    pub max_subscriptions: u32,
    pub max_monitored_items_per_sub: u32,
    pub max_array_length: u32,
    pub max_string_length: u32,
    pub max_byte_string_length: u32,
    pub min_sampling_interval: f64,
    pub min_publishing_interval: f64,
}

Fields

clients_can_modify_address_space: bool

Indicates if clients are able to modify the address space through the node management service set. This is a very broad flag and is likely to require more fine grained per user control in a later revision. By default, this value is false

max_subscriptions: u32

Maximum number of subscriptions in a session, 0 for no limit

max_monitored_items_per_sub: u32

Maximum number of monitored items per subscription, 0 for no limit

max_array_length: u32

Max array length in elements

max_string_length: u32

Max string length in characters

max_byte_string_length: u32

Max bytestring length in bytes

min_sampling_interval: f64

Specifies the minimum sampling interval for this server in seconds.

min_publishing_interval: f64

Specifies the minimum publishing interval for this server in seconds.