[−][src]Struct opcua_server::config::ServerUserToken
Fields
user: StringUser name
pass: Option<String>Password
x509: Option<String>thumbprint: Option<Thumbprint>Implementations
impl ServerUserToken[src]
pub fn user_pass<T>(user: T, pass: T) -> Self where
T: Into<String>, [src]
T: Into<String>,
Create a user pass token
pub fn x509<T>(user: T, cert_path: &PathBuf) -> Self where
T: Into<String>, [src]
T: Into<String>,
Create an X509 token.
pub fn read_thumbprint(&mut self)[src]
Read an X509 user token's certificate from disk and then hold onto the thumbprint for it.
pub fn is_valid(&self, id: &str) -> bool[src]
Test if the token is valid. This does not care for x509 tokens if the cert is present on the disk or not.
pub fn is_user_pass(&self) -> bool[src]
pub fn is_x509(&self) -> bool[src]