pub struct ServerDiagnostics { /* private fields */ }
Structure that captures diagnostics information for the server

Implementations

Return a completed summary of the server diagnostics as they stand. This structure is used to fill the address space stats about the server.

Increment the number of requests that were rejected due to security constraints since the server was started (or restarted). The requests include all Services defined in Part 4, also requests to create sessions.

Increment the number of requests that were rejected since the server was started (or restarted). The requests include all Services defined in Part 4, also requests to create sessions. This number includes the securityRejectedRequestsCount.

Increment the number of client sessions currently established in the server.

Decrement the number of client sessions currently established in the server.

Increment the number of subscriptions currently established in the server.

Decrement the number of subscriptions currently established in the server.

Increment the number of client sessions that were closed due to timeout since the server was started (or restarted).

Increment the number of server-created views in the server.

Increment the number of client sessions that were closed due to errors since the server was started (or restarted).

Increment the number of publishing intervals currently supported in the server.

Increment the number of requests that were rejected due to security constraints since the server was started (or restarted). The requests include all Services defined in Part 4, also requests to create sessions.

Increment the number of requests that were rejected since the server was started (or restarted). The requests include all Services defined in Part 4, also requests to create sessions. This number includes the securityRejectedRequestsCount.