Struct opcua_server::diagnostics::ServerDiagnostics
source · pub struct ServerDiagnostics { /* private fields */ }Expand description
Structure that captures diagnostics information for the server
Implementations
sourceimpl ServerDiagnostics
impl ServerDiagnostics
sourcepub fn server_diagnostics_summary(&self) -> &ServerDiagnosticsSummaryDataType
pub fn server_diagnostics_summary(&self) -> &ServerDiagnosticsSummaryDataType
Return a completed summary of the server diagnostics as they stand. This structure is used to fill the address space stats about the server.
sourcepub fn on_rejected_security_session(&mut self)
pub fn on_rejected_security_session(&mut self)
Increment the number of requests that were rejected due to security constraints since the server was started (or restarted). The requests include all Services defined in Part 4, also requests to create sessions.
sourcepub fn on_rejected_session(&mut self)
pub fn on_rejected_session(&mut self)
Increment the number of requests that were rejected since the server was started (or restarted). The requests include all Services defined in Part 4, also requests to create sessions. This number includes the securityRejectedRequestsCount.
sourcepub fn on_create_session(&mut self, _session: &Session)
pub fn on_create_session(&mut self, _session: &Session)
Increment the number of client sessions currently established in the server.
sourcepub fn on_destroy_session(&mut self, _session: &Session)
pub fn on_destroy_session(&mut self, _session: &Session)
Decrement the number of client sessions currently established in the server.
sourcepub fn on_create_subscription(&mut self, _subscription: &Subscription)
pub fn on_create_subscription(&mut self, _subscription: &Subscription)
Increment the number of subscriptions currently established in the server.
sourcepub fn on_destroy_subscription(&mut self, _subscription: &Subscription)
pub fn on_destroy_subscription(&mut self, _subscription: &Subscription)
Decrement the number of subscriptions currently established in the server.
sourcepub fn on_session_timeout(&mut self)
pub fn on_session_timeout(&mut self)
Increment the number of client sessions that were closed due to timeout since the server was started (or restarted).
sourcepub fn on_server_view(&mut self, _session: &Session)
pub fn on_server_view(&mut self, _session: &Session)
Increment the number of server-created views in the server.
sourcepub fn on_session_abort(&mut self, _session: &Session)
pub fn on_session_abort(&mut self, _session: &Session)
Increment the number of client sessions that were closed due to errors since the server was started (or restarted).
sourcepub fn on_publishing_interval(&mut self)
pub fn on_publishing_interval(&mut self)
Increment the number of publishing intervals currently supported in the server.
sourcepub fn on_security_rejected_request(&mut self)
pub fn on_security_rejected_request(&mut self)
Increment the number of requests that were rejected due to security constraints since the server was started (or restarted). The requests include all Services defined in Part 4, also requests to create sessions.
sourcepub fn on_rejected_request(&mut self)
pub fn on_rejected_request(&mut self)
Increment the number of requests that were rejected since the server was started (or restarted). The requests include all Services defined in Part 4, also requests to create sessions. This number includes the securityRejectedRequestsCount.