[−][src]Struct opcua_server::historical::HistoryServerCapabilities
Values that should be set in the address space via AddressSpace::set_history_server_capabilities()
to denote to clients what history capabilities the server has.
Fields
access_history_data: boolaccess_history_events: boolmax_return_data: u32max_return_events: u32insert_data: boolreplace_data: boolupdate_data: booldelete_raw: booldelete_at_time: boolinsert_event: boolreplace_event: boolupdate_event: booldelete_event: boolinsert_annotation: boolAuto Trait Implementations
impl RefUnwindSafe for HistoryServerCapabilities
impl Send for HistoryServerCapabilities
impl Sync for HistoryServerCapabilities
impl Unpin for HistoryServerCapabilities
impl UnwindSafe for HistoryServerCapabilities