Struct opcua_server::prelude::byte_string::ByteString
source · Expand description
A sequence of octets.
Fields
value: Option<Vec<u8, Global>>Implementations
sourceimpl ByteString
impl ByteString
sourcepub fn null() -> ByteString
pub fn null() -> ByteString
Create a null string (not the same as an empty string)
sourcepub fn is_null_or_empty(&self) -> bool
pub fn is_null_or_empty(&self) -> bool
Test if the string is null or empty
sourcepub fn from_base64(data: &str) -> Option<ByteString>
pub fn from_base64(data: &str) -> Option<ByteString>
Creates a byte string from a Base64 encoded string
sourcepub fn random(number_of_bytes: usize) -> ByteString
pub fn random(number_of_bytes: usize) -> ByteString
Create a byte string with a number of random characters. Can be used to create a nonce or a similar reason.