[−][src]Struct opcua_server::prelude::data_value::DataValue
A data value is a value of a variable in the OPC UA server and contains information about its value, status and change timestamps.
Fields
value: Option<Variant>The value. BaseDataType Not present if the Value bit in the EncodingMask is False.
status: Option<u32>The status associated with the value. Not present if the StatusCode bit in the EncodingMask is False Note we don't use StatusCode enum because extra bits can be set on the value
source_timestamp: Option<DateTime>The source timestamp associated with the value. Not present if the SourceTimestamp bit in the EncodingMask is False.
source_picoseconds: Option<i16>The number of 10 picosecond intervals for the SourceTimestamp. Not present if the SourcePicoSeconds bit in the EncodingMask is False. If the source timestamp is missing the picoseconds are ignored.
server_timestamp: Option<DateTime>The Server timestamp associated with the value. Not present if the ServerTimestamp bit in the EncodingMask is False.
server_picoseconds: Option<i16>The number of 10 picosecond intervals for the ServerTimestamp. Not present if the ServerPicoSeconds bit in the EncodingMask is False. If the Server timestamp is missing the picoseconds are ignored.
Methods
impl DataValue[src]
pub fn new<V>(value: V) -> DataValue where
V: Into<Variant>, [src]
V: Into<Variant>,
Creates a data value from the supplied value
pub fn null() -> DataValue[src]
Creates an empty DataValue
pub fn set_value<V>(
&mut self,
value: V,
source_timestamp: &DateTime,
server_timestamp: &DateTime
) where
V: Into<Variant>, [src]
&mut self,
value: V,
source_timestamp: &DateTime,
server_timestamp: &DateTime
) where
V: Into<Variant>,
Sets the value of the data value, updating the timestamps at the same point
pub fn status(&self) -> u32[src]
Returns the status code as a u32
pub fn is_valid(&self) -> bool[src]
Test if the value held by this data value is known to be good Anything other than Good is assumed to be invalid.