[−][src]Function opcua_server::prelude::encoding::write_array
pub fn write_array<S, T>(
stream: &mut S,
values: &Option<Vec<T>>
) -> Result<usize, StatusCode> where
S: Write,
T: BinaryEncoder<T>,
Write an array of the encoded type to stream, preserving distinction between null array and empty array