[−][src]Enum opcua_server::prelude::MessageSecurityMode
The MessageSecurityMode is an enumeration that specifies what security should be applied to messages exchanges during a Session.
Variants
InvalidThe MessageSecurityMode is invalid. This value is the default value to ensure that unless explicitly set, a connection will be rejected.
NoneNo security is applied. This assumes a plaintext security policy.
SignAll messages are signed but not encrypted.
SignAndEncryptAll messages are signed and encrypted.