pub enum MessageSecurityMode {
    Invalid,
    None,
    Sign,
    SignAndEncrypt,
}
The MessageSecurityMode is an enumeration that specifies what security should be applied to messages exchanges during a Session.

Variants



Invalid

The MessageSecurityMode is invalid. This value is the default value to avoid an accidental choice of no security is applied. This choice will always be rejected.



None

No security is applied.



Sign

All messages are signed but not encrypted.



SignAndEncrypt

All messages are signed and encrypted.