[−][src]Struct opcua_server::prelude::string::UAString
A string containing UTF-8 encoded characters.
A string can also be a null value, so the string value is optional. When there is no string, the value is treated as null
To avoid naming conflict hell, the String type is named UAString.
Fields
value: Option<String>Methods
impl UAString[src]
pub fn is_empty(&self) -> bool[src]
Returns true if the string is null or empty, false otherwise
pub fn len(&self) -> isize[src]
Returns the length of the string or -1 for null.
pub fn null() -> UAString[src]
Create a null string (not the same as an empty string).
pub fn is_null(&self) -> bool[src]
Test if the string is null.