[][src]Struct opcua_server::prelude::ByteString

pub struct ByteString {
    pub value: Option<Vec<u8>>,
}

A sequence of octets.

Fields

value: Option<Vec<u8>>

Implementations

impl ByteString[src]

pub fn null() -> ByteString[src]

Create a null string (not the same as an empty string)

pub fn is_null(&self) -> bool[src]

Test if the string is null

pub fn is_empty(&self) -> bool[src]

pub fn is_null_or_empty(&self) -> bool[src]

Test if the string is null or empty

pub fn from_base64(data: &str) -> Option<ByteString>[src]

Creates a byte string from a Base64 encoded string

pub fn as_base64(&self) -> String[src]

Encodes the bytestring as a Base64 encoded string

pub fn substring(&self, min: usize, max: usize) -> Result<ByteString, ()>[src]

This function is meant for use with NumericRange. It creates a substring from this string from min up to and inclusive of max. Note that min must have an index within the string but max is allowed to be beyond the end in which case the remainder of the string is returned (see docs for NumericRange).