Struct opcua_server::prelude::DecodingLimits [−][src]
pub struct DecodingLimits {
pub max_chunk_size: usize,
pub max_string_length: usize,
pub max_byte_string_length: usize,
pub max_array_length: usize,
}Fields
max_chunk_size: usizeMaximum size of a message chunk in bytes. 0 means no limit
max_string_length: usizeMaximum length in bytes (not chars!) of a string. 0 actually means 0, i.e. no string permitted
max_byte_string_length: usizeMaximum length in bytes of a byte string. 0 actually means 0, i.e. no byte string permitted
max_array_length: usizeMaximum number of array elements. 0 actually means 0, i.e. no array permitted
Implementations
This can be useful for decoding extension objects where the payload is not expected to contain any string or array.