pub struct DecodingLimits {
    pub max_string_length: u32,
    pub max_byte_string_length: u32,
    pub max_array_length: u32,
}

Fields

max_string_length: u32

Maximum length in bytes (not chars!) of a string. 0 actually means 0, i.e. no string permitted

max_byte_string_length: u32

Maximum length in bytes of a byte string. 0 actually means 0, i.e. no byte string permitted

max_array_length: u32

Maximum number of array elements. 0 actually means 0, i.e. no array permitted

Implementations

This can be useful for decoding extension objects where the payload is not expected to contain any string or array.