[][src]Struct opcua_server::prelude::ExtensionObject

pub struct ExtensionObject {
    pub node_id: NodeId,
    pub body: ExtensionObjectEncoding,
}

An extension object holds a serialized object identified by its node id.

Fields

node_id: NodeIdbody: ExtensionObjectEncoding

Implementations

impl ExtensionObject[src]

pub fn null() -> ExtensionObject[src]

Creates a null extension object, i.e. one with no value or payload

pub fn is_null(&self) -> bool[src]

Tests for null node id.

pub fn is_empty(&self) -> bool[src]

Tests for empty body.

pub fn object_id(&self) -> Result<ObjectId, ()>[src]

Returns the object id of the thing this extension object contains, assuming the object id can be recognised from the node id.

pub fn from_encodable<N, T>(node_id: N, encodable: &T) -> ExtensionObject where
    N: Into<NodeId>,
    T: BinaryEncoder<T>, 
[src]

Creates an extension object with the specified node id and the encodable object as its payload. The body is set to a byte string containing the encoded struct.

pub fn decode_inner<T>(
    &self,
    decoding_limits: &DecodingLimits
) -> Result<T, StatusCode> where
    T: BinaryEncoder<T>, 
[src]

Decodes the inner content of the extension object and returns it. The node id is ignored for decoding. The caller supplies the binary encoder impl that should be used to extract the data. Errors result in a decoding error.