Struct opcua_server::prelude::ExtensionObject
source · pub struct ExtensionObject {
pub node_id: NodeId,
pub body: ExtensionObjectEncoding,
}Expand description
An extension object holds a serialized object identified by its node id.
Fields
node_id: NodeIdbody: ExtensionObjectEncodingImplementations
sourceimpl ExtensionObject
impl ExtensionObject
sourcepub fn null() -> ExtensionObject
pub fn null() -> ExtensionObject
Creates a null extension object, i.e. one with no value or payload
sourcepub fn from_encodable<N, T>(node_id: N, encodable: &T) -> ExtensionObjectwhere
N: 'static + Into<NodeId>,
T: BinaryEncoder<T>,
pub fn from_encodable<N, T>(node_id: N, encodable: &T) -> ExtensionObjectwhere
N: 'static + Into<NodeId>,
T: BinaryEncoder<T>,
Creates an extension object with the specified node id and the encodable object as its payload. The body is set to a byte string containing the encoded struct.
sourcepub fn decode_inner<T>(
&self,
decoding_limits: &DecodingLimits
) -> Result<T, StatusCode>where
T: BinaryEncoder<T>,
pub fn decode_inner<T>(
&self,
decoding_limits: &DecodingLimits
) -> Result<T, StatusCode>where
T: BinaryEncoder<T>,
Decodes the inner content of the extension object and returns it. The node id is ignored for decoding. The caller supplies the binary encoder impl that should be used to extract the data. Errors result in a decoding error.