Struct opcua_server::prelude::ModifySubscriptionResponse [−][src]
pub struct ModifySubscriptionResponse {
pub response_header: ResponseHeader,
pub revised_publishing_interval: f64,
pub revised_lifetime_count: u32,
pub revised_max_keep_alive_count: u32,
}Fields
response_header: ResponseHeaderrevised_publishing_interval: f64revised_lifetime_count: u32revised_max_keep_alive_count: u32Trait Implementations
Returns the exact byte length of the structure as it would be if encode were called.
This may be called prior to writing to ensure the correct amount of space is available. Read more
Encodes the instance to the write stream.
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ModifySubscriptionResponse, StatusCode> where
S: Read,
pub fn decode<S>(
stream: &mut S,
decoding_limits: &DecodingLimits
) -> Result<ModifySubscriptionResponse, StatusCode> where
S: Read,
Decodes an instance from the read stream. The decoding limits are restrictions set by the server / client
on the length of strings, arrays etc. If these limits are exceeded the implementation should
return with a BadDecodingError as soon as possible. Read more
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.