[][src]Struct opcua_server::prelude::NotificationMessage

pub struct NotificationMessage {
    pub sequence_number: u32,
    pub publish_time: DateTime,
    pub notification_data: Option<Vec<ExtensionObject>>,
}

Fields

sequence_number: u32publish_time: DateTimenotification_data: Option<Vec<ExtensionObject>>

Implementations

impl NotificationMessage[src]

pub fn data_change(
    sequence_number: u32,
    publish_time: DateTime,
    data_change_notifications: Vec<MonitoredItemNotification>,
    event_notifications: Vec<EventFieldList>
) -> NotificationMessage
[src]

Create a notification message which contains data change AND / OR events. Calling this with neither will panic. Notification data can have up to 2 elements to covers the case in table 158 where a subscription contains monitored items for events and data.

pub fn status_change(
    sequence_number: u32,
    publish_time: DateTime,
    status: StatusCode
) -> NotificationMessage
[src]

Create a status change notification message

pub fn keep_alive(
    sequence_number: u32,
    publish_time: DateTime
) -> NotificationMessage
[src]

Create a keep-alive notification message

pub fn notifications(
    &self,
    decoding_limits: &DecodingLimits
) -> Option<(Vec<DataChangeNotification>, Vec<EventNotificationList>)>
[src]

Extract notifications from the message. Unrecognized / unparseable notifications will be ignored. If there are no notifications, the function will return None.