pub struct UAString {
    pub value: Option<String>,
}
A string containing UTF-8 encoded characters.

A string can also be a null value, so the string value is optional. When there is no string, the value is treated as null

To avoid naming conflict hell, the String type is named UAString.

Fields

value: Option<String>

Implementations

Returns true if the string is null or empty, false otherwise

Returns the length of the string or -1 for null.

Create a null string (not the same as an empty string).

Test if the string is null.