Struct opcua_server::prelude::UAString
source · Expand description
A string containing UTF-8 encoded characters.
A string can also be a null value, so the string value is optional. When there is no string, the value is treated as null
To avoid naming conflict hell, the String type is named UAString.
Fields
value: Option<String>Implementations