Struct opcua_server::prelude::WriteMask
source · pub struct WriteMask { /* private fields */ }Implementations
sourceimpl WriteMask
impl WriteMask
sourcepub const ACCESS_LEVEL: WriteMask = Self{ bits: 1,}
pub const ACCESS_LEVEL: WriteMask = Self{ bits: 1,}
Indicates if the AccessLevel Attribute is writable.
sourcepub const ARRAY_DIMENSTIONS: WriteMask = Self{ bits: 1 << 1,}
pub const ARRAY_DIMENSTIONS: WriteMask = Self{ bits: 1 << 1,}
Indicates if the ArrayDimensions Attribute is writable.
sourcepub const BROWSE_NAME: WriteMask = Self{ bits: 1 << 2,}
pub const BROWSE_NAME: WriteMask = Self{ bits: 1 << 2,}
Indicates if the BrowseName Attribute is writable.
sourcepub const CONTAINS_NO_LOOPS: WriteMask = Self{ bits: 1 << 3,}
pub const CONTAINS_NO_LOOPS: WriteMask = Self{ bits: 1 << 3,}
Indicates if the ContainsNoLoops Attribute is writable.
sourcepub const DATA_TYPE: WriteMask = Self{ bits: 1 << 4,}
pub const DATA_TYPE: WriteMask = Self{ bits: 1 << 4,}
Indicates if the DataType Attribute is writable.
sourcepub const DESCRIPTION: WriteMask = Self{ bits: 1 << 5,}
pub const DESCRIPTION: WriteMask = Self{ bits: 1 << 5,}
Indicates if the Description Attribute is writable.
sourcepub const DISPLAY_NAME: WriteMask = Self{ bits: 1 << 6,}
pub const DISPLAY_NAME: WriteMask = Self{ bits: 1 << 6,}
Indicates if the DisplayName Attribute is writable.
sourcepub const EVENT_NOTIFIER: WriteMask = Self{ bits: 1 << 7,}
pub const EVENT_NOTIFIER: WriteMask = Self{ bits: 1 << 7,}
Indicates if the EventNotifier Attribute is writable.
sourcepub const EXECUTABLE: WriteMask = Self{ bits: 1 << 8,}
pub const EXECUTABLE: WriteMask = Self{ bits: 1 << 8,}
Indicates if the Executable Attribute is writable.
sourcepub const HISTORIZING: WriteMask = Self{ bits: 1 << 9,}
pub const HISTORIZING: WriteMask = Self{ bits: 1 << 9,}
Indicates if the Historizing Attribute is writable.
sourcepub const INVERSE_NAME: WriteMask = Self{ bits: 1 << 10,}
pub const INVERSE_NAME: WriteMask = Self{ bits: 1 << 10,}
Indicates if the InverseName Attribute is writable.
sourcepub const IS_ABSTRACT: WriteMask = Self{ bits: 1 << 11,}
pub const IS_ABSTRACT: WriteMask = Self{ bits: 1 << 11,}
Indicates if the IsAbstract Attribute is writable.
sourcepub const MINIMUM_SAMPLING_INTERVAL: WriteMask = Self{ bits: 1 << 12,}
pub const MINIMUM_SAMPLING_INTERVAL: WriteMask = Self{ bits: 1 << 12,}
Indicates if the MinimumSamplingInterval Attribute is writable.
sourcepub const NODE_CLASS: WriteMask = Self{ bits: 1 << 13,}
pub const NODE_CLASS: WriteMask = Self{ bits: 1 << 13,}
Indicates if the NodeClass Attribute is writable.
sourcepub const NODE_ID: WriteMask = Self{ bits: 1 << 14,}
pub const NODE_ID: WriteMask = Self{ bits: 1 << 14,}
Indicates if the NodeId Attribute is writable.
sourcepub const SYMMETRIC: WriteMask = Self{ bits: 1 << 15,}
pub const SYMMETRIC: WriteMask = Self{ bits: 1 << 15,}
Indicates if the Symmetric Attribute is writable.
sourcepub const USER_ACCESS_LEVEL: WriteMask = Self{ bits: 1 << 16,}
pub const USER_ACCESS_LEVEL: WriteMask = Self{ bits: 1 << 16,}
Indicates if the UserAccessLevel Attribute is writable.
sourcepub const USER_EXECUTABLE: WriteMask = Self{ bits: 1 << 17,}
pub const USER_EXECUTABLE: WriteMask = Self{ bits: 1 << 17,}
Indicates if the UserExecutable Attribute is writable.
sourcepub const USER_WRITE_MASK: WriteMask = Self{ bits: 1 << 18,}
pub const USER_WRITE_MASK: WriteMask = Self{ bits: 1 << 18,}
Indicates if the UserWriteMask Attribute is writable.
sourcepub const VALUE_RANK: WriteMask = Self{ bits: 1 << 19,}
pub const VALUE_RANK: WriteMask = Self{ bits: 1 << 19,}
Indicates if the ValueRank Attribute is writable.
sourcepub const WRITE_MASK: WriteMask = Self{ bits: 1 << 20,}
pub const WRITE_MASK: WriteMask = Self{ bits: 1 << 20,}
Indicates if the WriteMask Attribute is writable.
sourcepub const VALUE_FOR_VARIABLE_TYPE: WriteMask = Self{ bits: 1 << 21,}
pub const VALUE_FOR_VARIABLE_TYPE: WriteMask = Self{ bits: 1 << 21,}
Indicates if the Value Attribute is writable for a VariableType. It does not apply for Variables since this is handled by the AccessLevel and UserAccessLevel Attributes for the Variable. For Variables this bit shall be set to 0.
sourcepub const fn from_bits(bits: u32) -> Option<WriteMask>
pub const fn from_bits(bits: u32) -> Option<WriteMask>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u32) -> WriteMask
pub const fn from_bits_truncate(bits: u32) -> WriteMask
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> WriteMask
pub const unsafe fn from_bits_unchecked(bits: u32) -> WriteMask
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: WriteMask) -> bool
pub const fn intersects(&self, other: WriteMask) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: WriteMask) -> bool
pub const fn contains(&self, other: WriteMask) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn set(&mut self, other: WriteMask, value: bool)
pub fn set(&mut self, other: WriteMask, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: WriteMask) -> WriteMask
pub const fn intersection(self, other: WriteMask) -> WriteMask
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: WriteMask) -> WriteMask
pub const fn union(self, other: WriteMask) -> WriteMask
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: WriteMask) -> WriteMask
pub const fn difference(self, other: WriteMask) -> WriteMask
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: WriteMask) -> WriteMask
pub const fn symmetric_difference(self, other: WriteMask) -> WriteMask
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> WriteMask
pub const fn complement(self) -> WriteMask
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.