pub struct ServerState {
Show 19 fields pub application_uri: UAString, pub product_uri: UAString, pub application_name: LocalizedText, pub base_endpoint: String, pub start_time: DateTime, pub namespaces: Vec<String>, pub servers: Vec<String>, pub config: Arc<RwLock<ServerConfig>>, pub server_certificate: Option<X509>, pub server_pkey: Option<PrivateKey>, pub last_subscription_id: u32, pub max_subscriptions: usize, pub min_publishing_interval: Duration, pub default_keep_alive_count: u32, pub max_keep_alive_count: u32, pub max_lifetime_count: u32, pub state: ServerStateType, pub abort: bool, pub diagnostics: Arc<RwLock<ServerDiagnostics>>,
}
Server state is any state associated with the server as a whole that individual sessions might be interested in. That includes configuration info etc.

Fields

application_uri: UAString

The application URI

product_uri: UAString

The product URI

application_name: LocalizedText

The application name

base_endpoint: String

The protocol, hostname and port formatted as a url, but less the path

start_time: DateTime

The time the server started

namespaces: Vec<String>

The list of namespaces

servers: Vec<String>

The list of servers (by urn)

config: Arc<RwLock<ServerConfig>>

Server configuration

server_certificate: Option<X509>

Server public certificate read from config location or null if there is none

server_pkey: Option<PrivateKey>

Server private key

last_subscription_id: u32

The next subscription id - subscriptions are shared across the whole server. Initial value is a random u32.

max_subscriptions: usize

Maximum number of subscriptions per session, 0 means no limit (danger)

min_publishing_interval: Duration

Minimum publishing interval

default_keep_alive_count: u32

Default keep alive count

max_keep_alive_count: u32

Maxmimum keep alive count

max_lifetime_count: u32

Maximum lifetime count (3 times as large as max keep alive)

state: ServerStateTypeabort: bool

Sets the abort flag that terminates the associated server

diagnostics: Arc<RwLock<ServerDiagnostics>>

Diagnostic information

Implementations

Make matching endpoint descriptions for the specified url. If none match then None will be passed, therefore if Some is returned it will be guaranteed to contain at least one result.

Authenticates access to an endpoint. The endpoint is described by its path, policy, mode and the token is supplied in an extension object that must be extracted and authenticated.

It is possible that the endpoint does not exist, or that the token is invalid / unsupported or that the token cannot be used with the end point. The return codes reflect the responses that ActivateSession would expect from a service call.