Struct opcua_server::subscriptions::PublishRequestEntry
[−]
[src]
pub struct PublishRequestEntry {
pub request_id: UInt32,
pub request: PublishRequest,
}The publish request entry preserves the request_id which is part of the chunk layer but clients are fickle about receiving responses from the same as the request. Normally this is easy because request and response are synchronous, but publish requests are async, so we preserve the request_id so that later we can send out responses that have the proper req id
Fields
request_id: UInt32
request: PublishRequest