[][src]Struct opcua_server::subscriptions::subscription::Subscription

pub struct Subscription { /* fields omitted */ }

Implementations

impl Subscription[src]

pub fn new(
    diagnostics: Arc<RwLock<ServerDiagnostics>>,
    subscription_id: u32,
    publishing_enabled: bool,
    publishing_interval: Duration,
    lifetime_counter: u32,
    keep_alive_counter: u32,
    priority: u8
) -> Subscription
[src]

pub fn monitored_items_len(&self) -> usize[src]

pub fn create_monitored_items(
    &mut self,
    address_space: &AddressSpace,
    now: &DateTimeUtc,
    timestamps_to_return: TimestampsToReturn,
    items_to_create: &[MonitoredItemCreateRequest],
    max_monitored_items_per_sub: usize
) -> Vec<MonitoredItemCreateResult>
[src]

Creates monitored items on the specified subscription, returning the creation results

pub fn modify_monitored_items(
    &mut self,
    address_space: &AddressSpace,
    timestamps_to_return: TimestampsToReturn,
    items_to_modify: &[MonitoredItemModifyRequest]
) -> Vec<MonitoredItemModifyResult>
[src]

Modify the specified monitored items, returning a result for each

pub fn set_monitoring_mode(
    &mut self,
    monitored_item_id: u32,
    monitoring_mode: MonitoringMode
) -> StatusCode
[src]

Sets the monitoring mode on one monitored item

pub fn delete_monitored_items(
    &mut self,
    items_to_delete: &[u32]
) -> Vec<StatusCode>
[src]

Delete the specified monitored items (by item id), returning a status code for each

pub fn get_handles(&self) -> (Vec<u32>, Vec<u32>)[src]

pub fn set_resend_data(&mut self)[src]

Sets the resend data flag which means the next publish request will receive the latest value of every monitored item whether it has changed in this cycle or not.

pub fn reset_keep_alive_counter(&mut self)[src]

Reset the keep-alive counter to the maximum keep-alive count of the Subscription. The maximum keep-alive count is set by the Client when the Subscription is created and may be modified using the ModifySubscription Service

pub fn reset_lifetime_counter(&mut self)[src]

Reset the lifetime counter to the value specified for the life time of the subscription in the create subscription service

pub fn start_publishing_timer(&mut self)[src]

Start or restart the publishing timer and decrement the LifetimeCounter Variable.

pub fn subscription_id(&self) -> u32[src]

pub fn lifetime_counter(&self) -> u32[src]

pub fn keep_alive_counter(&self) -> u32[src]

pub fn message_sent(&self) -> bool[src]

pub fn publishing_interval(&self) -> Duration[src]

pub fn max_keep_alive_count(&self) -> u32[src]

pub fn max_lifetime_count(&self) -> u32[src]

pub fn priority(&self) -> u8[src]